{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "c542d51c",
   "metadata": {},
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import math\n",
    "import json\n",
    "import glob\n",
    "from functools import reduce"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 37,
   "id": "1592981c",
   "metadata": {},
   "outputs": [],
   "source": [
    "def load_results(dataset, model, pretrained, ckpt, metric, n_sample, seed):\n",
    "    if pretrained:\n",
    "        result_dir = f'../results/{dataset}/pretrained/{model}_{seed}-{ckpt}/{metric}_{n_sample}'\n",
    "    else:\n",
    "        result_dir = f'../results/{dataset}/scratch/{model}_{seed}-{ckpt}/{metric}_{n_sample}'\n",
    "      \n",
    "    result_fs = glob.glob(f'{result_dir}/*.json')\n",
    "    results = []\n",
    "    for file in result_fs:\n",
    "        with open(file, 'r') as f:\n",
    "            data = json.load(f)\n",
    "        results.extend(data)\n",
    "    \n",
    "    print(f'{metric}: {len(results)}')\n",
    "        \n",
    "    return results"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 38,
   "id": "54321e39",
   "metadata": {},
   "outputs": [],
   "source": [
    "n_sample_dict = {\n",
    "    'CIFAR-10': -1, \n",
    "    'CIFAR-100': -1, \n",
    "    'Living-17': -1,\n",
    "    'Nonliving-26': -1,\n",
    "    'Entity-13': -1,\n",
    "    'Entity-30': -1,\n",
    "    'ImageNet': -1,\n",
    "    'RxRx1': -1,\n",
    "    'FMoW': -1,\n",
    "    'Amazon': -1,\n",
    "    'CivilComments': -1,\n",
    "    'Camelyon17': -1\n",
    "}\n",
    "\n",
    "n_epoch_dict = {\n",
    "    'CIFAR-10': 300, \n",
    "    'CIFAR-100': 300, \n",
    "    'Living-17': 450,\n",
    "    'Nonliving-26': 450,\n",
    "    'Entity-13': 300,\n",
    "    'Entity-30': 300,\n",
    "    'ImageNet': 10,\n",
    "    'FMoW': 50,\n",
    "    'RxRx1': 90,\n",
    "    'Amazon': 3,\n",
    "    'CivilComments': 5,\n",
    "    'Camelyon17': 5,\n",
    "}\n",
    "\n",
    "pretrained_dict = {\n",
    "    'CIFAR-10': False, \n",
    "    'CIFAR-100': False, \n",
    "    'Living-17': False,\n",
    "    'Nonliving-26': False,\n",
    "    'Entity-13': False,\n",
    "    'Entity-30': False,\n",
    "    'ImageNet': True,\n",
    "    'FMoW': True,\n",
    "    'RxRx1': True,\n",
    "    'Amazon': True,\n",
    "    'Camelyon17': True,\n",
    "    'CivilComments': True\n",
    "}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 105,
   "id": "13c79cfb",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "seed: 0\n",
      "AC: 192\n",
      "DoC: 192\n",
      "IM: 192\n",
      "GDE: 0\n",
      "ATC-MC: 192\n",
      "ATC-NE: 192\n",
      "COT: 192\n",
      "COTT-MC: 0\n",
      "\n"
     ]
    }
   ],
   "source": [
    "metrics = ['AC', 'DoC', 'IM', 'GDE', 'ATC-MC', 'ATC-NE', 'COT', 'COTT-MC']\n",
    "dataset = 'Nonliving-26'\n",
    "arch = 'resnet50' # \"distilbert-base-uncased\" #  \n",
    "n_sample = n_sample_dict[dataset]\n",
    "seeds = [0]\n",
    "model_ckpt = n_epoch_dict[dataset]\n",
    "pretrained = pretrained_dict[dataset]\n",
    "results = []\n",
    "for seed in seeds: \n",
    "    print(f'seed: {seed}')\n",
    "    results.append(\n",
    "        sum([load_results(dataset, arch, pretrained, model_ckpt, metric, n_sample, seed) for metric in metrics], [])\n",
    "    )\n",
    "    print()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 87,
   "id": "edb585d8",
   "metadata": {},
   "outputs": [],
   "source": [
    "import altair as alt\n",
    "import pandas as pd"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 88,
   "id": "ef90531d",
   "metadata": {},
   "outputs": [],
   "source": [
    "def get_corr_chart(data, subpop, scale_min=0, scale_max=1):\n",
    "    corr = alt.Chart(alt.Data(values=data), title=subpop).mark_point(size=40, filled=True).encode(\n",
    "        x=alt.X('metric:Q', scale=alt.Scale(domain=[scale_min, scale_max])),\n",
    "        y=alt.X('error:Q', scale=alt.Scale(domain=[scale_min, scale_max]), title='Test Error'),\n",
    "        color=alt.Color('ref:N'),\n",
    "        shape=alt.Color('ref:N'),\n",
    "    ).properties(\n",
    "        width=200,\n",
    "        height=200\n",
    "    )\n",
    "    return corr"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 89,
   "id": "86df21ae",
   "metadata": {},
   "outputs": [],
   "source": [
    "seed_ind = 0\n",
    "same_pop_results =  [i for i in results[seed_ind] if i['subpopulation'] == 'same']\n",
    "natural_pop_results =  [i for i in results[seed_ind] if i['subpopulation'] == 'natural']\n",
    "novel_pop_results = [i for i in results[seed_ind] if i['subpopulation'] == 'novel']"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 90,
   "id": "dc6e0c13",
   "metadata": {},
   "outputs": [],
   "source": [
    "scale_min = max( min( min([i['metric'] for i in results[seed_ind]]), min([i['error'] for i in results[seed_ind]]))  - 0.1,  0)\n",
    "scale_max = min( max( max([i['metric'] for i in results[seed_ind]]), max([i['error'] for i in results[seed_ind]]))  + 0.1,  1)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 91,
   "id": "fd94e84f",
   "metadata": {},
   "outputs": [],
   "source": [
    "line = pd.DataFrame({'metric': [scale_min, scale_max], 'error': [scale_min, scale_max]})\n",
    "line_plot = alt.Chart(line).mark_line(color='black', strokeDash=[5, 8]).encode(\n",
    "    x='metric',\n",
    "    y='error',\n",
    ")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 92,
   "id": "a2681d4c",
   "metadata": {},
   "outputs": [],
   "source": [
    "same_corr = get_corr_chart(same_pop_results, 'same', scale_min=scale_min, scale_max=scale_max)\n",
    "same_plt = same_corr + line_plot\n",
    "\n",
    "natural_corr = get_corr_chart(natural_pop_results, 'natural', scale_min=scale_min, scale_max=scale_max)\n",
    "natural_plt = natural_corr + line_plot\n",
    "\n",
    "novel_corr = get_corr_chart(novel_pop_results, 'novel', scale_min=scale_min, scale_max=scale_max)\n",
    "novel_plt = novel_corr + line_plot\n",
    "\n",
    "plt = same_plt | natural_plt | novel_plt"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 93,
   "id": "3c3d3a92",
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/usr/workspace/lu35/anaconda3/envs/ood/lib/python3.9/site-packages/altair/utils/core.py:317: FutureWarning: iteritems is deprecated and will be removed in a future version. Use .items instead.\n",
      "  for col_name, dtype in df.dtypes.iteritems():\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-95cfed49eb1244088a6067f5e2e9ab98\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-95cfed49eb1244088a6067f5e2e9ab98\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-95cfed49eb1244088a6067f5e2e9ab98\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"4.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}, \"axis\": {\"labelFontSize\": 14, \"titleFontSize\": 16}, \"legend\": {\"labelFontSize\": 16, \"titleFontSize\": 14}}, \"hconcat\": [{\"layer\": [{\"data\": {\"values\": [{\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.2568644881248474, \"ref\": \"AC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2757343649864197, \"ref\": \"AC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3115326166152954, \"ref\": \"AC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.35167503356933594, \"ref\": \"AC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.4004688262939453, \"ref\": \"AC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.43235844373703003, \"ref\": \"AC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4235934019088745, \"ref\": \"AC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.47854429483413696, \"ref\": \"AC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5275174379348755, \"ref\": \"AC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5414751768112183, \"ref\": \"AC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5555287003517151, \"ref\": \"AC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.31508690118789673, \"ref\": \"AC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3634428381919861, \"ref\": \"AC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.30039507150650024, \"ref\": \"AC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.30689364671707153, \"ref\": \"AC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3142198324203491, \"ref\": \"AC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5173218846321106, \"ref\": \"AC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5705099403858185, \"ref\": \"AC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6146951913833618, \"ref\": \"AC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6128545999526978, \"ref\": \"AC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6282166242599487, \"ref\": \"AC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.40627431869506836, \"ref\": \"AC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.4860004186630249, \"ref\": \"AC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5068871676921844, \"ref\": \"AC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5087341368198395, \"ref\": \"AC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5195918679237366, \"ref\": \"AC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.33688002824783325, \"ref\": \"AC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.4611722230911255, \"ref\": \"AC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5243490040302277, \"ref\": \"AC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.551519513130188, \"ref\": \"AC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5791822671890259, \"ref\": \"AC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.32120001316070557, \"ref\": \"AC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.3800828456878662, \"ref\": \"AC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.4611818194389343, \"ref\": \"AC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5828442871570587, \"ref\": \"AC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.692400187253952, \"ref\": \"AC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3497634530067444, \"ref\": \"AC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.3931087851524353, \"ref\": \"AC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4160890579223633, \"ref\": \"AC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4337628483772278, \"ref\": \"AC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.4872071146965027, \"ref\": \"AC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.3562542200088501, \"ref\": \"AC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.41133034229278564, \"ref\": \"AC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.4724235534667969, \"ref\": \"AC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6040696501731873, \"ref\": \"AC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6938558518886566, \"ref\": \"AC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2849518656730652, \"ref\": \"AC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.29590940475463867, \"ref\": \"AC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.30416232347488403, \"ref\": \"AC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.3299342393875122, \"ref\": \"AC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.3663238286972046, \"ref\": \"AC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.32796841859817505, \"ref\": \"AC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.36960601806640625, \"ref\": \"AC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.41963648796081543, \"ref\": \"AC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4589439630508423, \"ref\": \"AC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.4917163848876953, \"ref\": \"AC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.2874819040298462, \"ref\": \"AC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.29132741689682007, \"ref\": \"AC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3182024359703064, \"ref\": \"AC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.33626312017440796, \"ref\": \"AC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.35883229970932007, \"ref\": \"AC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.36758190393447876, \"ref\": \"AC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.3872603178024292, \"ref\": \"AC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3053441643714905, \"ref\": \"AC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.36036139726638794, \"ref\": \"AC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3246811032295227, \"ref\": \"AC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.32264894247055054, \"ref\": \"AC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.3896932601928711, \"ref\": \"AC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.45665597915649414, \"ref\": \"AC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5721624493598938, \"ref\": \"AC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6585875749588013, \"ref\": \"AC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.38735753297805786, \"ref\": \"AC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.47611188888549805, \"ref\": \"AC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.47042399644851685, \"ref\": \"AC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.48758333921432495, \"ref\": \"AC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5116956532001495, \"ref\": \"AC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27347052097320557, \"ref\": \"AC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3169790506362915, \"ref\": \"AC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3514191508293152, \"ref\": \"AC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.3833431005477905, \"ref\": \"AC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.41982966661453247, \"ref\": \"AC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.3092450499534607, \"ref\": \"AC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3326406478881836, \"ref\": \"AC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.41445469856262207, \"ref\": \"AC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.4618861675262451, \"ref\": \"AC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5255265235900879, \"ref\": \"AC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.3676217198371887, \"ref\": \"AC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.3969155550003052, \"ref\": \"AC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4254905581474304, \"ref\": \"AC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.4437023997306824, \"ref\": \"AC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.4569217562675476, \"ref\": \"AC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5291972458362579, \"ref\": \"AC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6179554760456085, \"ref\": \"AC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.6912234723567963, \"ref\": \"AC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7472858428955078, \"ref\": \"AC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.7533613294363022, \"ref\": \"AC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.25478007633592825, \"ref\": \"DoC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2736499531975005, \"ref\": \"DoC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.30944820482637625, \"ref\": \"DoC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3495906217804168, \"ref\": \"DoC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.39838441450502615, \"ref\": \"DoC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.43027403194811087, \"ref\": \"DoC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.42150899011995535, \"ref\": \"DoC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.4764598830452178, \"ref\": \"DoC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5254330261459563, \"ref\": \"DoC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5393907650222991, \"ref\": \"DoC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5534442885627959, \"ref\": \"DoC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.31300248939897757, \"ref\": \"DoC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3613584264030669, \"ref\": \"DoC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.2983106597175811, \"ref\": \"DoC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3048092349281524, \"ref\": \"DoC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.31213542063142996, \"ref\": \"DoC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5152374728431914, \"ref\": \"DoC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5684255285968993, \"ref\": \"DoC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6126107795944427, \"ref\": \"DoC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6107701881637786, \"ref\": \"DoC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6261322124710296, \"ref\": \"DoC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4041899069061492, \"ref\": \"DoC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.48391600687410574, \"ref\": \"DoC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5048027559032653, \"ref\": \"DoC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5066497250309203, \"ref\": \"DoC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5175074561348174, \"ref\": \"DoC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3347956164589141, \"ref\": \"DoC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.45908781130220633, \"ref\": \"DoC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5222645922413085, \"ref\": \"DoC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5494351013412688, \"ref\": \"DoC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5770978554001067, \"ref\": \"DoC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.3191156013717864, \"ref\": \"DoC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.37799843389894705, \"ref\": \"DoC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.45909740765001517, \"ref\": \"DoC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5807598753681396, \"ref\": \"DoC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.6903157754650329, \"ref\": \"DoC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3476790412178252, \"ref\": \"DoC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.39102437336351614, \"ref\": \"DoC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4140046461334441, \"ref\": \"DoC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4316784365883086, \"ref\": \"DoC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.4851227029075835, \"ref\": \"DoC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.35416980821993094, \"ref\": \"DoC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.4092459305038665, \"ref\": \"DoC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.4703391416778777, \"ref\": \"DoC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6019852383842681, \"ref\": \"DoC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6917714400997375, \"ref\": \"DoC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.282867453884146, \"ref\": \"DoC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.2938249929657195, \"ref\": \"DoC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3020779116859649, \"ref\": \"DoC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.32784982759859305, \"ref\": \"DoC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.36423941690828543, \"ref\": \"DoC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.3258840068092559, \"ref\": \"DoC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.3675216062774871, \"ref\": \"DoC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.41755207617189627, \"ref\": \"DoC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4568595512619231, \"ref\": \"DoC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.48963197309877615, \"ref\": \"DoC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.28539749224092703, \"ref\": \"DoC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.2892430051079009, \"ref\": \"DoC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.31611802418138724, \"ref\": \"DoC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3341787083854888, \"ref\": \"DoC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.3567478879204009, \"ref\": \"DoC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.3654974921455596, \"ref\": \"DoC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.38517590601351004, \"ref\": \"DoC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3032597525825713, \"ref\": \"DoC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.3582769854774688, \"ref\": \"DoC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.32259669144060354, \"ref\": \"DoC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.3205645306816314, \"ref\": \"DoC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.38760884840395193, \"ref\": \"DoC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.454571567367575, \"ref\": \"DoC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5700780375709746, \"ref\": \"DoC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6565031631698821, \"ref\": \"DoC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.3852731211891387, \"ref\": \"DoC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.4740274770965789, \"ref\": \"DoC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.4683395846595977, \"ref\": \"DoC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.4854989274254058, \"ref\": \"DoC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5096112414112304, \"ref\": \"DoC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.2713861091842864, \"ref\": \"DoC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.31489463884737234, \"ref\": \"DoC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.349334739040396, \"ref\": \"DoC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.38125868875887137, \"ref\": \"DoC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.4177452548256133, \"ref\": \"DoC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.30716063816454153, \"ref\": \"DoC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.33055623609926443, \"ref\": \"DoC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.4123702867737029, \"ref\": \"DoC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.45980175573732596, \"ref\": \"DoC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5234421118011687, \"ref\": \"DoC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.36553730804826956, \"ref\": \"DoC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.394831143211386, \"ref\": \"DoC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.42340614635851126, \"ref\": \"DoC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.4416179879417632, \"ref\": \"DoC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.45483734447862845, \"ref\": \"DoC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5271128340473388, \"ref\": \"DoC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6158710642566894, \"ref\": \"DoC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.6891390605678771, \"ref\": \"DoC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7452014311065887, \"ref\": \"DoC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.751276917647383, \"ref\": \"DoC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.25716009323634914, \"ref\": \"IM\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.27182131298769163, \"ref\": \"IM\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3052949516099641, \"ref\": \"IM\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3406618501919695, \"ref\": \"IM\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.3854842531279785, \"ref\": \"IM\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.4125669341295911, \"ref\": \"IM\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.40479085534949977, \"ref\": \"IM\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.4533133858895976, \"ref\": \"IM\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.49690618418552823, \"ref\": \"IM\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5080775942660181, \"ref\": \"IM\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5229041568037729, \"ref\": \"IM\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.30975979444181934, \"ref\": \"IM\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3520658448179034, \"ref\": \"IM\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.29465649540879535, \"ref\": \"IM\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.29982664132490267, \"ref\": \"IM\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.30712604014804423, \"ref\": \"IM\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.4889361158242328, \"ref\": \"IM\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5369614448016979, \"ref\": \"IM\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.5718427099146223, \"ref\": \"IM\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.5704443877149948, \"ref\": \"IM\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.5862072010053286, \"ref\": \"IM\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.3901240999285097, \"ref\": \"IM\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.4608745991327776, \"ref\": \"IM\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.4804122786628471, \"ref\": \"IM\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.48116743859050437, \"ref\": \"IM\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.4886822288817799, \"ref\": \"IM\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3293204447827015, \"ref\": \"IM\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.438473889453069, \"ref\": \"IM\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.4946016096776157, \"ref\": \"IM\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5182032393039437, \"ref\": \"IM\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.541928524407825, \"ref\": \"IM\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.3143797472483836, \"ref\": \"IM\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.3658080917081823, \"ref\": \"IM\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.43940186202326237, \"ref\": \"IM\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5458186227391473, \"ref\": \"IM\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.6414839732423757, \"ref\": \"IM\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3398797068216083, \"ref\": \"IM\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.37838694548818463, \"ref\": \"IM\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.40022765365115565, \"ref\": \"IM\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4151348150381263, \"ref\": \"IM\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.4627910489114939, \"ref\": \"IM\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.3451654167036663, \"ref\": \"IM\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.3949109698169252, \"ref\": \"IM\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.44918823929227125, \"ref\": \"IM\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.5647013110481147, \"ref\": \"IM\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6438810170586922, \"ref\": \"IM\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2812951666750573, \"ref\": \"IM\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.29204147546402914, \"ref\": \"IM\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.29891642990861267, \"ref\": \"IM\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.32129162233255026, \"ref\": \"IM\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.35417964144596426, \"ref\": \"IM\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.3191185747731238, \"ref\": \"IM\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.35922184159745363, \"ref\": \"IM\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4024443794819299, \"ref\": \"IM\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4357319882783123, \"ref\": \"IM\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.4665593065029109, \"ref\": \"IM\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.2830214472070959, \"ref\": \"IM\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.2878841711818829, \"ref\": \"IM\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.31227537791948823, \"ref\": \"IM\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3275792194138023, \"ref\": \"IM\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.34975010797886197, \"ref\": \"IM\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.35659357460205066, \"ref\": \"IM\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.3744270390501737, \"ref\": \"IM\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.29841258677748483, \"ref\": \"IM\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.3478406283335359, \"ref\": \"IM\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3170442460872074, \"ref\": \"IM\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.3154025518496011, \"ref\": \"IM\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.37483989364719894, \"ref\": \"IM\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.4339121256827645, \"ref\": \"IM\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5374856038540184, \"ref\": \"IM\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6107221892042698, \"ref\": \"IM\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.37343702005236146, \"ref\": \"IM\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.4520547164481403, \"ref\": \"IM\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.44820420981297326, \"ref\": \"IM\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.4615258067213752, \"ref\": \"IM\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.48335133699722166, \"ref\": \"IM\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27175339078601146, \"ref\": \"IM\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3089444184783502, \"ref\": \"IM\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3428077407036074, \"ref\": \"IM\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.3694104135647115, \"ref\": \"IM\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.40317434799092056, \"ref\": \"IM\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.30196351072099836, \"ref\": \"IM\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3247973093394235, \"ref\": \"IM\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.39971511343818733, \"ref\": \"IM\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.4389499656040299, \"ref\": \"IM\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.49575090273982625, \"ref\": \"IM\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.355278323567524, \"ref\": \"IM\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.3838473812039347, \"ref\": \"IM\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4069917761661508, \"ref\": \"IM\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.42351477249902725, \"ref\": \"IM\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.43545197416707526, \"ref\": \"IM\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.4999234612043285, \"ref\": \"IM\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.5755587824465013, \"ref\": \"IM\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.6382958464483546, \"ref\": \"IM\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.6858710254014728, \"ref\": \"IM\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.6905633722476795, \"ref\": \"IM\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.26, \"ref\": \"ATC-MC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2817647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.32823529411764707, \"ref\": \"ATC-MC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3835294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.46647058823529414, \"ref\": \"ATC-MC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5005882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4970588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.5788235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6405882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.6564705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.6729411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.32588235294117646, \"ref\": \"ATC-MC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.40647058823529414, \"ref\": \"ATC-MC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3111764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3264705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3311764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.63, \"ref\": \"ATC-MC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7194117647058823, \"ref\": \"ATC-MC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.7841176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.78, \"ref\": \"ATC-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8017647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4611764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.5764705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6141176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6141176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6352941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.36, \"ref\": \"ATC-MC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5429411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6370588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.6741176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7158823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.34058823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4235294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5358823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7558823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9364705882352942, \"ref\": \"ATC-MC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.37529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.43823529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4711764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4929411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.5852941176470589, \"ref\": \"ATC-MC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.38823529411764707, \"ref\": \"ATC-MC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.45647058823529413, \"ref\": \"ATC-MC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.571764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.7911764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2888235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.3076470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3088235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.34941176470588237, \"ref\": \"ATC-MC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.4, \"ref\": \"ATC-MC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.34058823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4023529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.47352941176470587, \"ref\": \"ATC-MC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.5358823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.5835294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.29411764705882354, \"ref\": \"ATC-MC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.29058823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3323529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.36, \"ref\": \"ATC-MC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.3947058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.3982352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4294117647058823, \"ref\": \"ATC-MC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.31176470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.38294117647058823, \"ref\": \"ATC-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.34058823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.3341176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4370588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5364705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7329411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8705882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4323529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5570588235294117, \"ref\": \"ATC-MC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.5576470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.5752941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6223529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27647058823529413, \"ref\": \"ATC-MC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.32823529411764707, \"ref\": \"ATC-MC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.37470588235294117, \"ref\": \"ATC-MC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.42470588235294116, \"ref\": \"ATC-MC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.4858823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.32235294117647056, \"ref\": \"ATC-MC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.47705882352941176, \"ref\": \"ATC-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.5447058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6552941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.4023529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4464705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5047058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5276470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5364705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.65, \"ref\": \"ATC-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.7870588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.8929411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9664705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.97, \"ref\": \"ATC-MC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.25470588235294117, \"ref\": \"ATC-NE\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2847058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.34058823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.4123529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.48176470588235293, \"ref\": \"ATC-NE\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5364705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.5223529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6176470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6964705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.7247058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7376470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.32941176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.41411764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3164705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.32588235294117646, \"ref\": \"ATC-NE\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.33941176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.6905882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7705882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8352941176470589, \"ref\": \"ATC-NE\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8376470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8629411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.49411764705882355, \"ref\": \"ATC-NE\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6294117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6735294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6758823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6905882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.36941176470588233, \"ref\": \"ATC-NE\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5929411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6935294117647058, \"ref\": \"ATC-NE\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7364705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7794117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.34941176470588237, \"ref\": \"ATC-NE\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.44588235294117645, \"ref\": \"ATC-NE\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5935294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.8023529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9594117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3876470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.45529411764705885, \"ref\": \"ATC-NE\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.48, \"ref\": \"ATC-NE\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5041176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6082352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4088235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.49058823529411766, \"ref\": \"ATC-NE\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6111764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.841764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9688235294117648, \"ref\": \"ATC-NE\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.30176470588235293, \"ref\": \"ATC-NE\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.30941176470588233, \"ref\": \"ATC-NE\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.31941176470588234, \"ref\": \"ATC-NE\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.36176470588235293, \"ref\": \"ATC-NE\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.43176470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.34294117647058825, \"ref\": \"ATC-NE\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4076470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4988235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.5605882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.63, \"ref\": \"ATC-NE\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.29823529411764704, \"ref\": \"ATC-NE\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.3029411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.33941176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3652941176470588, \"ref\": \"ATC-NE\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.39705882352941174, \"ref\": \"ATC-NE\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.39235294117647057, \"ref\": \"ATC-NE\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.42705882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.31588235294117645, \"ref\": \"ATC-NE\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.39705882352941174, \"ref\": \"ATC-NE\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3488235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.35352941176470587, \"ref\": \"ATC-NE\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4682352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5723529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.78, \"ref\": \"ATC-NE\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.9023529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4582352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6129411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6047058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6188235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6888235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.28823529411764703, \"ref\": \"ATC-NE\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3388235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3941176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.44588235294117645, \"ref\": \"ATC-NE\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5135294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.3311764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3623529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5105882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.5888235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6876470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.4335294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4747058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5135294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5411764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5629411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.7094117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.851764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9364705882352942, \"ref\": \"ATC-NE\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9835294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9847058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.2597547769546509, \"ref\": \"COT\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.28364914655685425, \"ref\": \"COT\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.32408615946769714, \"ref\": \"COT\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3725247383117676, \"ref\": \"COT\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.42994654178619385, \"ref\": \"COT\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.47961851954460144, \"ref\": \"COT\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.48512211441993713, \"ref\": \"COT\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.5528350472450256, \"ref\": \"COT\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6313156485557556, \"ref\": \"COT\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.6857916116714478, \"ref\": \"COT\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7212618589401245, \"ref\": \"COT\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.3303042948246002, \"ref\": \"COT\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3745395541191101, \"ref\": \"COT\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.31732824444770813, \"ref\": \"COT\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3231368064880371, \"ref\": \"COT\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.33568498492240906, \"ref\": \"COT\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5680691599845886, \"ref\": \"COT\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.627562940120697, \"ref\": \"COT\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6784297227859497, \"ref\": \"COT\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6858649849891663, \"ref\": \"COT\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.7263993620872498, \"ref\": \"COT\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4415108263492584, \"ref\": \"COT\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.5707955360412598, \"ref\": \"COT\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6318899393081665, \"ref\": \"COT\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6426894068717957, \"ref\": \"COT\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6763434410095215, \"ref\": \"COT\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3727335035800934, \"ref\": \"COT\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5319917798042297, \"ref\": \"COT\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6178784370422363, \"ref\": \"COT\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.6698164343833923, \"ref\": \"COT\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7333115339279175, \"ref\": \"COT\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.33300405740737915, \"ref\": \"COT\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4486319422721863, \"ref\": \"COT\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5765623450279236, \"ref\": \"COT\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.6873120069503784, \"ref\": \"COT\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.800870418548584, \"ref\": \"COT\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3897415101528168, \"ref\": \"COT\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.45413628220558167, \"ref\": \"COT\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5009185671806335, \"ref\": \"COT\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5513011813163757, \"ref\": \"COT\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6340348720550537, \"ref\": \"COT\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4079698622226715, \"ref\": \"COT\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5235734581947327, \"ref\": \"COT\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.5965194702148438, \"ref\": \"COT\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.7092363834381104, \"ref\": \"COT\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.8032971024513245, \"ref\": \"COT\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2954219579696655, \"ref\": \"COT\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.3071881830692291, \"ref\": \"COT\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3152823746204376, \"ref\": \"COT\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.34416335821151733, \"ref\": \"COT\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.38211050629615784, \"ref\": \"COT\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.3634728789329529, \"ref\": \"COT\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.42441093921661377, \"ref\": \"COT\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.49816060066223145, \"ref\": \"COT\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.563321590423584, \"ref\": \"COT\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.5979713201522827, \"ref\": \"COT\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.30407315492630005, \"ref\": \"COT\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.31269219517707825, \"ref\": \"COT\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.34457528591156006, \"ref\": \"COT\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3714539408683777, \"ref\": \"COT\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.3979353606700897, \"ref\": \"COT\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4470289945602417, \"ref\": \"COT\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.5048344731330872, \"ref\": \"COT\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3447875380516052, \"ref\": \"COT\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.5448209643363953, \"ref\": \"COT\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.6298406720161438, \"ref\": \"COT\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.34143954515457153, \"ref\": \"COT\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4635319709777832, \"ref\": \"COT\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5719571709632874, \"ref\": \"COT\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.6811544895172119, \"ref\": \"COT\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.7504749298095703, \"ref\": \"COT\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.41457849740982056, \"ref\": \"COT\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5549600124359131, \"ref\": \"COT\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.5699336528778076, \"ref\": \"COT\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6375501155853271, \"ref\": \"COT\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6619479060173035, \"ref\": \"COT\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.2796747088432312, \"ref\": \"COT\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.32875916361808777, \"ref\": \"COT\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3838213384151459, \"ref\": \"COT\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.43477925658226013, \"ref\": \"COT\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5038549304008484, \"ref\": \"COT\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.32363075017929077, \"ref\": \"COT\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3728671073913574, \"ref\": \"COT\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5132740139961243, \"ref\": \"COT\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.575835108757019, \"ref\": \"COT\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6427764296531677, \"ref\": \"COT\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.41094791889190674, \"ref\": \"COT\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4539673626422882, \"ref\": \"COT\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4920126497745514, \"ref\": \"COT\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5154080390930176, \"ref\": \"COT\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5407332181930542, \"ref\": \"COT\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5661094784736633, \"ref\": \"COT\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6662365794181824, \"ref\": \"COT\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7670374512672424, \"ref\": \"COT\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.8464444279670715, \"ref\": \"COT\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.8611334562301636, \"ref\": \"COT\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.2605882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2823529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3876470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.47705882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5305882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.538235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6329411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.7188235294117648, \"ref\": \"COTT-MC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.788235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.8258823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.3264705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.40705882352941175, \"ref\": \"COTT-MC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3123529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3270588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.6335294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7235294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.7888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.7805882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8164705882352942, \"ref\": \"COTT-MC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.48705882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.65, \"ref\": \"COTT-MC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.7188235294117648, \"ref\": \"COTT-MC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.7358823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.7705882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3735294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5982352941176471, \"ref\": \"COTT-MC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.7047058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7723529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.8458823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.34294117647058825, \"ref\": \"COTT-MC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.49, \"ref\": \"COTT-MC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6211764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7741176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9364705882352942, \"ref\": \"COTT-MC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.38941176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.47705882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5911764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.7194117647058823, \"ref\": \"COTT-MC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5564705882352942, \"ref\": \"COTT-MC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6588235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.7941176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.941764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.3076470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3111764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.3517647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.40176470588235297, \"ref\": \"COTT-MC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.36470588235294116, \"ref\": \"COTT-MC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5405882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6270588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.6694117647058824, \"ref\": \"COTT-MC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.29470588235294115, \"ref\": \"COTT-MC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.2917647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.37176470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.40705882352941175, \"ref\": \"COTT-MC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.46352941176470586, \"ref\": \"COTT-MC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.5288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.35058823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.59, \"ref\": \"COTT-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.6852941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.34823529411764703, \"ref\": \"COTT-MC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.49470588235294116, \"ref\": \"COTT-MC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6176470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7623529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8705882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4429411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6052941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6429411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.7152941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.74, \"ref\": \"COTT-MC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27705882352941175, \"ref\": \"COTT-MC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3323529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.40058823529411763, \"ref\": \"COTT-MC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.46352941176470586, \"ref\": \"COTT-MC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5441176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.33, \"ref\": \"COTT-MC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.37588235294117645, \"ref\": \"COTT-MC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.548235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.6164705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7094117647058824, \"ref\": \"COTT-MC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.41705882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4711764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5294117647058824, \"ref\": \"COTT-MC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5547058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5852941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.6511764705882352, \"ref\": \"COTT-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.7888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.8929411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9664705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.97, \"ref\": \"COTT-MC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}]}, \"mark\": {\"type\": \"point\", \"filled\": true, \"size\": 40}, \"encoding\": {\"color\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"shape\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"x\": {\"field\": \"metric\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"title\": \"Test Error\", \"type\": \"quantitative\"}}, \"height\": 200, \"title\": \"same\", \"width\": 200}, {\"data\": {\"name\": \"data-55cc1c487e8b42cf39f3db1ac778f185\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"strokeDash\": [5, 8]}, \"encoding\": {\"x\": {\"field\": \"metric\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"type\": \"quantitative\"}}}]}, {\"layer\": [{\"data\": {\"values\": []}, \"mark\": {\"type\": \"point\", \"filled\": true, \"size\": 40}, \"encoding\": {\"color\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"shape\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"x\": {\"field\": \"metric\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"title\": \"Test Error\", \"type\": \"quantitative\"}}, \"height\": 200, \"title\": \"natural\", \"width\": 200}, {\"data\": {\"name\": \"data-55cc1c487e8b42cf39f3db1ac778f185\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"strokeDash\": [5, 8]}, \"encoding\": {\"x\": {\"field\": \"metric\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"type\": \"quantitative\"}}}]}, {\"layer\": [{\"data\": {\"values\": [{\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.3780967593193054, \"ref\": \"AC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.39695751667022705, \"ref\": \"AC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.41386252641677856, \"ref\": \"AC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.43405014276504517, \"ref\": \"AC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.4573761820793152, \"ref\": \"AC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.47702038288116455, \"ref\": \"AC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4846135377883911, \"ref\": \"AC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.5294855237007141, \"ref\": \"AC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5591286420822144, \"ref\": \"AC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5576261281967163, \"ref\": \"AC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.567700982093811, \"ref\": \"AC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.4118562340736389, \"ref\": \"AC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.45009469985961914, \"ref\": \"AC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.400867760181427, \"ref\": \"AC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.4022074341773987, \"ref\": \"AC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.4092528820037842, \"ref\": \"AC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5763581395149231, \"ref\": \"AC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.6121435165405273, \"ref\": \"AC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.63865065574646, \"ref\": \"AC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6350048184394836, \"ref\": \"AC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6479489207267761, \"ref\": \"AC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4846227169036865, \"ref\": \"AC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.5232641696929932, \"ref\": \"AC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.536354660987854, \"ref\": \"AC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5381816327571869, \"ref\": \"AC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.54063481092453, \"ref\": \"AC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.4255608320236206, \"ref\": \"AC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5131724178791046, \"ref\": \"AC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5598265528678894, \"ref\": \"AC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5736616849899292, \"ref\": \"AC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5902145206928253, \"ref\": \"AC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.4291214346885681, \"ref\": \"AC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4699832797050476, \"ref\": \"AC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5252754390239716, \"ref\": \"AC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.6086850166320801, \"ref\": \"AC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.7055111825466156, \"ref\": \"AC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.4333786964416504, \"ref\": \"AC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.46102970838546753, \"ref\": \"AC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.46343332529067993, \"ref\": \"AC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.46968406438827515, \"ref\": \"AC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.5068310499191284, \"ref\": \"AC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.45206236839294434, \"ref\": \"AC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.47509580850601196, \"ref\": \"AC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.520398736000061, \"ref\": \"AC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6177420318126678, \"ref\": \"AC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6975194811820984, \"ref\": \"AC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4063732624053955, \"ref\": \"AC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.41582077741622925, \"ref\": \"AC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4095945358276367, \"ref\": \"AC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.43215590715408325, \"ref\": \"AC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.4491746425628662, \"ref\": \"AC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4197562336921692, \"ref\": \"AC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4439573287963867, \"ref\": \"AC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.45921963453292847, \"ref\": \"AC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.48855018615722656, \"ref\": \"AC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.5179789364337921, \"ref\": \"AC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.39999502897262573, \"ref\": \"AC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.40187060832977295, \"ref\": \"AC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.41538864374160767, \"ref\": \"AC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.4244142770767212, \"ref\": \"AC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.4330263137817383, \"ref\": \"AC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4257560968399048, \"ref\": \"AC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.420701801776886, \"ref\": \"AC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.39900392293930054, \"ref\": \"AC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.4121248722076416, \"ref\": \"AC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3551621437072754, \"ref\": \"AC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.4374951124191284, \"ref\": \"AC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4631597399711609, \"ref\": \"AC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5059977769851685, \"ref\": \"AC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.6100777387619019, \"ref\": \"AC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6715035140514374, \"ref\": \"AC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.46514636278152466, \"ref\": \"AC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5189014077186584, \"ref\": \"AC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.48551446199417114, \"ref\": \"AC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.49427884817123413, \"ref\": \"AC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5335798859596252, \"ref\": \"AC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.3906547427177429, \"ref\": \"AC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.41698557138442993, \"ref\": \"AC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.4411352276802063, \"ref\": \"AC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.4604078531265259, \"ref\": \"AC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.4773411154747009, \"ref\": \"AC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4244615435600281, \"ref\": \"AC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.43703174591064453, \"ref\": \"AC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.474457323551178, \"ref\": \"AC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.5133640170097351, \"ref\": \"AC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5639317631721497, \"ref\": \"AC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.44915032386779785, \"ref\": \"AC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4623013138771057, \"ref\": \"AC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.47439461946487427, \"ref\": \"AC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.48336899280548096, \"ref\": \"AC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.49252569675445557, \"ref\": \"AC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5896462202072144, \"ref\": \"AC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6501660943031311, \"ref\": \"AC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7021885216236115, \"ref\": \"AC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7412725389003754, \"ref\": \"AC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.7507978230714798, \"ref\": \"AC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.37601234753038626, \"ref\": \"DoC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.3948731048813079, \"ref\": \"DoC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.4117781146278594, \"ref\": \"DoC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.431965730976126, \"ref\": \"DoC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.455291770290396, \"ref\": \"DoC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.4749359710922454, \"ref\": \"DoC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.48252912599947195, \"ref\": \"DoC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.527401111911795, \"ref\": \"DoC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5570442302932952, \"ref\": \"DoC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5555417164077971, \"ref\": \"DoC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5656165703048919, \"ref\": \"DoC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.40977182228471976, \"ref\": \"DoC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.4480102880707, \"ref\": \"DoC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.39878334839250784, \"ref\": \"DoC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.4001230223884795, \"ref\": \"DoC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.407168470214865, \"ref\": \"DoC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5742737277260039, \"ref\": \"DoC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.6100591047516082, \"ref\": \"DoC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6365662439575408, \"ref\": \"DoC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6329204066505645, \"ref\": \"DoC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.645864508937857, \"ref\": \"DoC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.48253830511476736, \"ref\": \"DoC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.521179757904074, \"ref\": \"DoC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5342702491989348, \"ref\": \"DoC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5360972209682677, \"ref\": \"DoC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5385503991356109, \"ref\": \"DoC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.42347642023470145, \"ref\": \"DoC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5110880060901855, \"ref\": \"DoC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5577421410789702, \"ref\": \"DoC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.57157727320101, \"ref\": \"DoC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5881301089039062, \"ref\": \"DoC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.42703702289964895, \"ref\": \"DoC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.46789886791612845, \"ref\": \"DoC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5231910272350524, \"ref\": \"DoC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.6066006048431609, \"ref\": \"DoC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.7034267707576964, \"ref\": \"DoC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.43129428465273123, \"ref\": \"DoC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.45894529659654837, \"ref\": \"DoC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.46134891350176077, \"ref\": \"DoC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.467599652599356, \"ref\": \"DoC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.5047466381302093, \"ref\": \"DoC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4499779566040252, \"ref\": \"DoC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.4730113967170928, \"ref\": \"DoC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.5183143242111419, \"ref\": \"DoC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6156576200237487, \"ref\": \"DoC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6954350693931792, \"ref\": \"DoC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.40428885061647635, \"ref\": \"DoC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4137363656273101, \"ref\": \"DoC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.40751012403871756, \"ref\": \"DoC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.4300714953651641, \"ref\": \"DoC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.44709023077394705, \"ref\": \"DoC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.41767182190325003, \"ref\": \"DoC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.44187291700746756, \"ref\": \"DoC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4571352227440093, \"ref\": \"DoC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4864657743683074, \"ref\": \"DoC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.515894524644873, \"ref\": \"DoC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.39791061718370657, \"ref\": \"DoC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.3997861965408538, \"ref\": \"DoC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4133042319526885, \"ref\": \"DoC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.42232986528780203, \"ref\": \"DoC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.4309419019928191, \"ref\": \"DoC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4236716850509856, \"ref\": \"DoC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4186173899879668, \"ref\": \"DoC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3969195111503814, \"ref\": \"DoC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.41004046041872244, \"ref\": \"DoC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.35307773191835623, \"ref\": \"DoC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.43541070063020926, \"ref\": \"DoC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.46107532818224173, \"ref\": \"DoC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5039133651962493, \"ref\": \"DoC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.6079933269729827, \"ref\": \"DoC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6694191022625182, \"ref\": \"DoC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4630619509926055, \"ref\": \"DoC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5168169959297393, \"ref\": \"DoC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.483430050205252, \"ref\": \"DoC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.49219443638231497, \"ref\": \"DoC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5314954741707061, \"ref\": \"DoC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.38857033092882376, \"ref\": \"DoC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.41490115959551077, \"ref\": \"DoC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.43905081589128714, \"ref\": \"DoC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.4583234413376067, \"ref\": \"DoC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.47525670368578177, \"ref\": \"DoC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4223771317711089, \"ref\": \"DoC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.43494733412172537, \"ref\": \"DoC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.4723729117622588, \"ref\": \"DoC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.511279605220816, \"ref\": \"DoC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5618473513832305, \"ref\": \"DoC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.4470659120788787, \"ref\": \"DoC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.46021690208818655, \"ref\": \"DoC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4723102076759551, \"ref\": \"DoC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.4812845810165618, \"ref\": \"DoC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.4904412849655364, \"ref\": \"DoC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5875618084182952, \"ref\": \"DoC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6480816825142119, \"ref\": \"DoC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7001041098346923, \"ref\": \"DoC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7391881271114562, \"ref\": \"DoC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.7487134112825606, \"ref\": \"DoC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.3643117923245659, \"ref\": \"IM\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.3826233899218616, \"ref\": \"IM\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3964088893836726, \"ref\": \"IM\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.4138902475123467, \"ref\": \"IM\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.4367357190812696, \"ref\": \"IM\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.45267069600806953, \"ref\": \"IM\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4600789524397767, \"ref\": \"IM\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.498720208925473, \"ref\": \"IM\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5260576669874083, \"ref\": \"IM\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5223313415214244, \"ref\": \"IM\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.532975550990546, \"ref\": \"IM\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.3949540276289484, \"ref\": \"IM\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.4300396907195273, \"ref\": \"IM\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3856943855579513, \"ref\": \"IM\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.38524739675926933, \"ref\": \"IM\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3920936183530447, \"ref\": \"IM\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.540145261057588, \"ref\": \"IM\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5719861171290961, \"ref\": \"IM\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.5938340905010482, \"ref\": \"IM\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.5928452284525466, \"ref\": \"IM\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6026192581705492, \"ref\": \"IM\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4610875450067208, \"ref\": \"IM\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.49368194808439203, \"ref\": \"IM\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5047439052859292, \"ref\": \"IM\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5067523116064665, \"ref\": \"IM\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5078763396893868, \"ref\": \"IM\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.4088845564443362, \"ref\": \"IM\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.48367390662263055, \"ref\": \"IM\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5252630438382432, \"ref\": \"IM\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5381867237072835, \"ref\": \"IM\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5528998763739983, \"ref\": \"IM\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.41168458914717665, \"ref\": \"IM\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4487482438560305, \"ref\": \"IM\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.4972630123910068, \"ref\": \"IM\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5702683893780462, \"ref\": \"IM\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.6523034787808488, \"ref\": \"IM\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.41572461933588944, \"ref\": \"IM\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.439669506975752, \"ref\": \"IM\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4419794676224824, \"ref\": \"IM\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4481839958018755, \"ref\": \"IM\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.47963008404083407, \"ref\": \"IM\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4329143046262258, \"ref\": \"IM\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.45220623482717803, \"ref\": \"IM\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.49216046651164946, \"ref\": \"IM\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.5769308717676249, \"ref\": \"IM\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6440985781824723, \"ref\": \"IM\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.38851783763559933, \"ref\": \"IM\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.39978539077619546, \"ref\": \"IM\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3940852340287673, \"ref\": \"IM\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.41550147854997765, \"ref\": \"IM\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.4278007052298811, \"ref\": \"IM\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4030042191214347, \"ref\": \"IM\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.42403336155061244, \"ref\": \"IM\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4375153308728289, \"ref\": \"IM\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.46188807410234434, \"ref\": \"IM\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.4909933174437796, \"ref\": \"IM\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.3833011314011383, \"ref\": \"IM\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.3857791235487359, \"ref\": \"IM\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3963729026492828, \"ref\": \"IM\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.405794191264082, \"ref\": \"IM\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.4160862365918566, \"ref\": \"IM\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4084402058449864, \"ref\": \"IM\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4033629735746834, \"ref\": \"IM\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3837169055614543, \"ref\": \"IM\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.3954517554810635, \"ref\": \"IM\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.34402138711566077, \"ref\": \"IM\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.41867182294924266, \"ref\": \"IM\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.44158000144083553, \"ref\": \"IM\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.4811957942342181, \"ref\": \"IM\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5697009084137358, \"ref\": \"IM\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6196490048286629, \"ref\": \"IM\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4436289551105236, \"ref\": \"IM\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.4897826323338419, \"ref\": \"IM\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.46186490992634643, \"ref\": \"IM\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.47068873154685875, \"ref\": \"IM\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5038971810054611, \"ref\": \"IM\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.3782692194373669, \"ref\": \"IM\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.4014104107948506, \"ref\": \"IM\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.42272245503620054, \"ref\": \"IM\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.440217105003713, \"ref\": \"IM\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.45466701116287067, \"ref\": \"IM\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4064889752079379, \"ref\": \"IM\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.418093023156499, \"ref\": \"IM\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.45094646557801865, \"ref\": \"IM\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.48644267857188306, \"ref\": \"IM\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5298598071116044, \"ref\": \"IM\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.42821631051119935, \"ref\": \"IM\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.44094649112175865, \"ref\": \"IM\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.451617232981422, \"ref\": \"IM\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.45902033097740547, \"ref\": \"IM\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.4686720691059, \"ref\": \"IM\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.549576354385005, \"ref\": \"IM\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6045315784505358, \"ref\": \"IM\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.647699139734954, \"ref\": \"IM\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.6812393365975284, \"ref\": \"IM\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.6878350822755324, \"ref\": \"IM\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.4052941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.4470588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.46705882352941175, \"ref\": \"ATC-MC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.49823529411764705, \"ref\": \"ATC-MC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5323529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5629411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.5682352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6429411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6935294117647058, \"ref\": \"ATC-MC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.69, \"ref\": \"ATC-MC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.6982352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.46352941176470586, \"ref\": \"ATC-MC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.5258823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.43529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.44, \"ref\": \"ATC-MC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.45294117647058824, \"ref\": \"ATC-MC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.7276470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.778235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8152941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8147058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.841764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.5782352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6276470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6558823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6564705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6652941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.47823529411764704, \"ref\": \"ATC-MC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.6152941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6882352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7123529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7382352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.4929411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.5564705882352942, \"ref\": \"ATC-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6523529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7911764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9529411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.4958823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.538235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5305882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5394117647058824, \"ref\": \"ATC-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6047058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5176470588235295, \"ref\": \"ATC-MC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6417647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.8158823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9352941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4476470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4717647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4641176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.49058823529411766, \"ref\": \"ATC-MC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.5188235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.47705882352941176, \"ref\": \"ATC-MC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5123529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5141176470588236, \"ref\": \"ATC-MC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.5647058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.6376470588235295, \"ref\": \"ATC-MC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.4411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.43941176470588234, \"ref\": \"ATC-MC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4547058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.47294117647058825, \"ref\": \"ATC-MC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.49529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4752941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.44941176470588234, \"ref\": \"ATC-MC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.43529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.46352941176470586, \"ref\": \"ATC-MC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3864705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.4976470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.5417647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6205882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7858823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8858823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.5435294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.62, \"ref\": \"ATC-MC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.5788235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6011764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6535294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.42, \"ref\": \"ATC-MC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.46294117647058824, \"ref\": \"ATC-MC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.508235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5376470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.57, \"ref\": \"ATC-MC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4788235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.49470588235294116, \"ref\": \"ATC-MC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5588235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.6329411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7176470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5152941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5388235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5511764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5776470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.59, \"ref\": \"ATC-MC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.7517647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.8358823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9117647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9576470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9588235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.3982352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.4323529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.48411764705882354, \"ref\": \"ATC-NE\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.5211764705882352, \"ref\": \"ATC-NE\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5641176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5935294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.601764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6905882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.7458823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.7488235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7741176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.48, \"ref\": \"ATC-NE\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.5252941176470588, \"ref\": \"ATC-NE\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.43529411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.43529411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.45529411764705885, \"ref\": \"ATC-NE\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.7752941176470588, \"ref\": \"ATC-NE\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.8405882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8794117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8764705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8905882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.601764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6835294117647058, \"ref\": \"ATC-NE\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.7229411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.7247058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.7447058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.48705882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.658235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.75, \"ref\": \"ATC-NE\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7764705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.8094117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.5088235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.5835294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6923529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.8464705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9711764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.5011764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.5535294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5358823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5529411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6276470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5323529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5864705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6923529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.8711764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9694117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.45294117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4711764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4641176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.5058823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.5311764705882352, \"ref\": \"ATC-NE\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4811764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5247058823529411, \"ref\": \"ATC-NE\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5388235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6111764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.6705882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.44176470588235295, \"ref\": \"ATC-NE\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.43941176470588234, \"ref\": \"ATC-NE\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4723529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.48823529411764705, \"ref\": \"ATC-NE\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.5, \"ref\": \"ATC-NE\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4764705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4611764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.4335294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.48823529411764705, \"ref\": \"ATC-NE\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.40058823529411763, \"ref\": \"ATC-NE\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.5164705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.5688235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6541176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.8370588235294117, \"ref\": \"ATC-NE\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.9229411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.5811764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6841176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6064705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6329411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.72, \"ref\": \"ATC-NE\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.43117647058823527, \"ref\": \"ATC-NE\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.47352941176470587, \"ref\": \"ATC-NE\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.5176470588235295, \"ref\": \"ATC-NE\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5547058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5994117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.49176470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.5135294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5935294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.6611764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7458823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5464705882352942, \"ref\": \"ATC-NE\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5658823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5858823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.6064705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.6229411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.8058823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.8905882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9547058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9829411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9776470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.40150293707847595, \"ref\": \"COT\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.4300719201564789, \"ref\": \"COT\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.4520876407623291, \"ref\": \"COT\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.4767075777053833, \"ref\": \"COT\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5057112574577332, \"ref\": \"COT\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5349220633506775, \"ref\": \"COT\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.5646870136260986, \"ref\": \"COT\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6169809699058533, \"ref\": \"COT\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6747012734413147, \"ref\": \"COT\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.7098894119262695, \"ref\": \"COT\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7345565557479858, \"ref\": \"COT\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.4544151723384857, \"ref\": \"COT\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.48047712445259094, \"ref\": \"COT\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.44845402240753174, \"ref\": \"COT\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.45146453380584717, \"ref\": \"COT\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.46480876207351685, \"ref\": \"COT\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.6328473687171936, \"ref\": \"COT\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.6732017993927002, \"ref\": \"COT\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.7040827870368958, \"ref\": \"COT\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.7084375619888306, \"ref\": \"COT\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.7426605820655823, \"ref\": \"COT\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.5454940795898438, \"ref\": \"COT\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6229733228683472, \"ref\": \"COT\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6640750169754028, \"ref\": \"COT\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.674493670463562, \"ref\": \"COT\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6965135335922241, \"ref\": \"COT\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.48631203174591064, \"ref\": \"COT\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5994735360145569, \"ref\": \"COT\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6650173664093018, \"ref\": \"COT\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7016424536705017, \"ref\": \"COT\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7459292411804199, \"ref\": \"COT\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.45920148491859436, \"ref\": \"COT\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.5513779520988464, \"ref\": \"COT\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6498664617538452, \"ref\": \"COT\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7187883257865906, \"ref\": \"COT\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.8087755441665649, \"ref\": \"COT\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.500562310218811, \"ref\": \"COT\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.5459010601043701, \"ref\": \"COT\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5743295550346375, \"ref\": \"COT\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.6144309639930725, \"ref\": \"COT\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6710925698280334, \"ref\": \"COT\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5276420712471008, \"ref\": \"COT\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.6154480576515198, \"ref\": \"COT\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6553532481193542, \"ref\": \"COT\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.729812741279602, \"ref\": \"COT\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.804345428943634, \"ref\": \"COT\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4414002597332001, \"ref\": \"COT\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4489256739616394, \"ref\": \"COT\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4446273148059845, \"ref\": \"COT\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.46758735179901123, \"ref\": \"COT\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.48444661498069763, \"ref\": \"COT\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4825882315635681, \"ref\": \"COT\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5224575996398926, \"ref\": \"COT\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5633591413497925, \"ref\": \"COT\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6088371872901917, \"ref\": \"COT\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.635463535785675, \"ref\": \"COT\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.44590291380882263, \"ref\": \"COT\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.4507793188095093, \"ref\": \"COT\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.472085565328598, \"ref\": \"COT\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.48805585503578186, \"ref\": \"COT\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.5006052851676941, \"ref\": \"COT\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.5512992143630981, \"ref\": \"COT\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.576546847820282, \"ref\": \"COT\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.44300368428230286, \"ref\": \"COT\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.6030905842781067, \"ref\": \"COT\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.6805370450019836, \"ref\": \"COT\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.4669661819934845, \"ref\": \"COT\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.5615561008453369, \"ref\": \"COT\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6384527087211609, \"ref\": \"COT\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7167212963104248, \"ref\": \"COT\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.7662137150764465, \"ref\": \"COT\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.5301109552383423, \"ref\": \"COT\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6111229062080383, \"ref\": \"COT\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6131497025489807, \"ref\": \"COT\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6573466658592224, \"ref\": \"COT\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6760717630386353, \"ref\": \"COT\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.42657867074012756, \"ref\": \"COT\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.45736321806907654, \"ref\": \"COT\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.4992476999759674, \"ref\": \"COT\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5145454406738281, \"ref\": \"COT\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5591875910758972, \"ref\": \"COT\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4488810896873474, \"ref\": \"COT\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.4855291247367859, \"ref\": \"COT\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5926111340522766, \"ref\": \"COT\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.638629674911499, \"ref\": \"COT\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6820104122161865, \"ref\": \"COT\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5120770335197449, \"ref\": \"COT\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5366452932357788, \"ref\": \"COT\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5583893060684204, \"ref\": \"COT\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5735103487968445, \"ref\": \"COT\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5923134684562683, \"ref\": \"COT\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.6322148442268372, \"ref\": \"COT\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.701309323310852, \"ref\": \"COT\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7750825881958008, \"ref\": \"COT\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.8396369814872742, \"ref\": \"COT\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.8551613688468933, \"ref\": \"COT\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.43058823529411766, \"ref\": \"COTT-MC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.46941176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.48823529411764705, \"ref\": \"COTT-MC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.52, \"ref\": \"COTT-MC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5541176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5947058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.6288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.7058823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.7835294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.8264705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.851764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.4929411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.5417647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.4682352941176471, \"ref\": \"COTT-MC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.4752941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.5094117647058823, \"ref\": \"COTT-MC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.7376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7811764705882352, \"ref\": \"COTT-MC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8170588235294117, \"ref\": \"COTT-MC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8147058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8511764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.6423529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.7188235294117648, \"ref\": \"COTT-MC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.7658823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.7776470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.7988235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.5229411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.678235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.77, \"ref\": \"COTT-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.8152941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.87, \"ref\": \"COTT-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.4970588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.6258823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.7341176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.8076470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9529411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.5435294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.6029411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.6158823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.6647058823529411, \"ref\": \"COTT-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.7570588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5882352941176471, \"ref\": \"COTT-MC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.6788235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.7364705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.8305882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9352941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4711764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.49058823529411766, \"ref\": \"COTT-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.48411764705882354, \"ref\": \"COTT-MC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.5076470588235295, \"ref\": \"COTT-MC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.5258823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.5241176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5723529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.6152941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6829411764705883, \"ref\": \"COTT-MC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.7335294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.47411764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.4717647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4958823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.5141176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.5376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.5888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.6041176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.46941176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.6735294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.7505882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.5023529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.6252941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.7241176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.8105882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8864705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.6011764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.678235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.7023529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.7470588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.7564705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.45, \"ref\": \"COTT-MC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.48764705882352943, \"ref\": \"COTT-MC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.5570588235294117, \"ref\": \"COTT-MC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5552941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5994117647058823, \"ref\": \"COTT-MC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.48, \"ref\": \"COTT-MC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.5141176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.6429411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.7047058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7623529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5417647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5735294117647058, \"ref\": \"COTT-MC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5952941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.6217647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.6458823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.7529411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.8370588235294117, \"ref\": \"COTT-MC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9117647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9576470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9588235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}]}, \"mark\": {\"type\": \"point\", \"filled\": true, \"size\": 40}, \"encoding\": {\"color\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"shape\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"x\": {\"field\": \"metric\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"title\": \"Test Error\", \"type\": \"quantitative\"}}, \"height\": 200, \"title\": \"novel\", \"width\": 200}, {\"data\": {\"name\": \"data-55cc1c487e8b42cf39f3db1ac778f185\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"strokeDash\": [5, 8]}, \"encoding\": {\"x\": {\"field\": \"metric\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"type\": \"quantitative\"}}}]}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.17.0.json\", \"datasets\": {\"data-55cc1c487e8b42cf39f3db1ac778f185\": [{\"metric\": 0.15470588235294117, \"error\": 0.15470588235294117}, {\"metric\": 1.0, \"error\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.HConcatChart(...)"
      ]
     },
     "execution_count": 93,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "plt.configure_axis(\n",
    "    labelFontSize=14,\n",
    "    titleFontSize=16\n",
    ").configure_axis(\n",
    "    labelFontSize=14,\n",
    "    titleFontSize=16,\n",
    ").configure_legend(\n",
    "    titleFontSize=14,\n",
    "    labelFontSize=16\n",
    ")\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 94,
   "id": "3ccfbce1",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-c2d75b7b0dc644f3a5c5b4050f147647\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-c2d75b7b0dc644f3a5c5b4050f147647\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-c2d75b7b0dc644f3a5c5b4050f147647\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"4.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"values\": [{\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.2568644881248474, \"ref\": \"AC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.3780967593193054, \"ref\": \"AC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2757343649864197, \"ref\": \"AC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.39695751667022705, \"ref\": \"AC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3115326166152954, \"ref\": \"AC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.41386252641677856, \"ref\": \"AC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.35167503356933594, \"ref\": \"AC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.43405014276504517, \"ref\": \"AC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.4004688262939453, \"ref\": \"AC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.4573761820793152, \"ref\": \"AC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.43235844373703003, \"ref\": \"AC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.47702038288116455, \"ref\": \"AC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4235934019088745, \"ref\": \"AC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4846135377883911, \"ref\": \"AC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.47854429483413696, \"ref\": \"AC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.5294855237007141, \"ref\": \"AC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5275174379348755, \"ref\": \"AC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5591286420822144, \"ref\": \"AC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5414751768112183, \"ref\": \"AC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5576261281967163, \"ref\": \"AC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5555287003517151, \"ref\": \"AC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.567700982093811, \"ref\": \"AC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.31508690118789673, \"ref\": \"AC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.4118562340736389, \"ref\": \"AC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3634428381919861, \"ref\": \"AC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.45009469985961914, \"ref\": \"AC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.30039507150650024, \"ref\": \"AC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.400867760181427, \"ref\": \"AC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.30689364671707153, \"ref\": \"AC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.4022074341773987, \"ref\": \"AC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3142198324203491, \"ref\": \"AC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.4092528820037842, \"ref\": \"AC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5173218846321106, \"ref\": \"AC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5763581395149231, \"ref\": \"AC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5705099403858185, \"ref\": \"AC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.6121435165405273, \"ref\": \"AC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6146951913833618, \"ref\": \"AC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.63865065574646, \"ref\": \"AC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6128545999526978, \"ref\": \"AC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6350048184394836, \"ref\": \"AC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6282166242599487, \"ref\": \"AC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6479489207267761, \"ref\": \"AC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.40627431869506836, \"ref\": \"AC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4846227169036865, \"ref\": \"AC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.4860004186630249, \"ref\": \"AC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.5232641696929932, \"ref\": \"AC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5068871676921844, \"ref\": \"AC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.536354660987854, \"ref\": \"AC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5087341368198395, \"ref\": \"AC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5381816327571869, \"ref\": \"AC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5195918679237366, \"ref\": \"AC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.54063481092453, \"ref\": \"AC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.33688002824783325, \"ref\": \"AC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.4255608320236206, \"ref\": \"AC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.4611722230911255, \"ref\": \"AC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5131724178791046, \"ref\": \"AC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5243490040302277, \"ref\": \"AC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5598265528678894, \"ref\": \"AC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.551519513130188, \"ref\": \"AC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5736616849899292, \"ref\": \"AC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5791822671890259, \"ref\": \"AC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5902145206928253, \"ref\": \"AC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.32120001316070557, \"ref\": \"AC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.4291214346885681, \"ref\": \"AC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.3800828456878662, \"ref\": \"AC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4699832797050476, \"ref\": \"AC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.4611818194389343, \"ref\": \"AC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5252754390239716, \"ref\": \"AC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5828442871570587, \"ref\": \"AC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.6086850166320801, \"ref\": \"AC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.692400187253952, \"ref\": \"AC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.7055111825466156, \"ref\": \"AC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3497634530067444, \"ref\": \"AC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.4333786964416504, \"ref\": \"AC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.3931087851524353, \"ref\": \"AC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.46102970838546753, \"ref\": \"AC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4160890579223633, \"ref\": \"AC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.46343332529067993, \"ref\": \"AC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4337628483772278, \"ref\": \"AC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.46968406438827515, \"ref\": \"AC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.4872071146965027, \"ref\": \"AC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.5068310499191284, \"ref\": \"AC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.3562542200088501, \"ref\": \"AC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.45206236839294434, \"ref\": \"AC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.41133034229278564, \"ref\": \"AC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.47509580850601196, \"ref\": \"AC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.4724235534667969, \"ref\": \"AC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.520398736000061, \"ref\": \"AC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6040696501731873, \"ref\": \"AC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6177420318126678, \"ref\": \"AC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6938558518886566, \"ref\": \"AC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6975194811820984, \"ref\": \"AC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2849518656730652, \"ref\": \"AC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4063732624053955, \"ref\": \"AC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.29590940475463867, \"ref\": \"AC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.41582077741622925, \"ref\": \"AC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.30416232347488403, \"ref\": \"AC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4095945358276367, \"ref\": \"AC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.3299342393875122, \"ref\": \"AC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.43215590715408325, \"ref\": \"AC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.3663238286972046, \"ref\": \"AC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.4491746425628662, \"ref\": \"AC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.32796841859817505, \"ref\": \"AC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4197562336921692, \"ref\": \"AC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.36960601806640625, \"ref\": \"AC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4439573287963867, \"ref\": \"AC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.41963648796081543, \"ref\": \"AC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.45921963453292847, \"ref\": \"AC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4589439630508423, \"ref\": \"AC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.48855018615722656, \"ref\": \"AC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.4917163848876953, \"ref\": \"AC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.5179789364337921, \"ref\": \"AC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.2874819040298462, \"ref\": \"AC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.39999502897262573, \"ref\": \"AC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.29132741689682007, \"ref\": \"AC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.40187060832977295, \"ref\": \"AC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3182024359703064, \"ref\": \"AC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.41538864374160767, \"ref\": \"AC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.33626312017440796, \"ref\": \"AC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.4244142770767212, \"ref\": \"AC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.35883229970932007, \"ref\": \"AC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.4330263137817383, \"ref\": \"AC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.36758190393447876, \"ref\": \"AC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4257560968399048, \"ref\": \"AC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.3872603178024292, \"ref\": \"AC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.420701801776886, \"ref\": \"AC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3053441643714905, \"ref\": \"AC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.39900392293930054, \"ref\": \"AC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.36036139726638794, \"ref\": \"AC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.4121248722076416, \"ref\": \"AC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3246811032295227, \"ref\": \"AC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3551621437072754, \"ref\": \"AC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.32264894247055054, \"ref\": \"AC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.4374951124191284, \"ref\": \"AC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.3896932601928711, \"ref\": \"AC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4631597399711609, \"ref\": \"AC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.45665597915649414, \"ref\": \"AC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5059977769851685, \"ref\": \"AC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5721624493598938, \"ref\": \"AC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.6100777387619019, \"ref\": \"AC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6585875749588013, \"ref\": \"AC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6715035140514374, \"ref\": \"AC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.38735753297805786, \"ref\": \"AC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.46514636278152466, \"ref\": \"AC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.47611188888549805, \"ref\": \"AC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5189014077186584, \"ref\": \"AC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.47042399644851685, \"ref\": \"AC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.48551446199417114, \"ref\": \"AC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.48758333921432495, \"ref\": \"AC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.49427884817123413, \"ref\": \"AC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5116956532001495, \"ref\": \"AC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5335798859596252, \"ref\": \"AC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27347052097320557, \"ref\": \"AC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.3906547427177429, \"ref\": \"AC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3169790506362915, \"ref\": \"AC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.41698557138442993, \"ref\": \"AC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3514191508293152, \"ref\": \"AC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.4411352276802063, \"ref\": \"AC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.3833431005477905, \"ref\": \"AC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.4604078531265259, \"ref\": \"AC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.41982966661453247, \"ref\": \"AC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.4773411154747009, \"ref\": \"AC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.3092450499534607, \"ref\": \"AC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4244615435600281, \"ref\": \"AC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3326406478881836, \"ref\": \"AC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.43703174591064453, \"ref\": \"AC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.41445469856262207, \"ref\": \"AC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.474457323551178, \"ref\": \"AC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.4618861675262451, \"ref\": \"AC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.5133640170097351, \"ref\": \"AC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5255265235900879, \"ref\": \"AC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5639317631721497, \"ref\": \"AC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.3676217198371887, \"ref\": \"AC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.44915032386779785, \"ref\": \"AC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.3969155550003052, \"ref\": \"AC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4623013138771057, \"ref\": \"AC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4254905581474304, \"ref\": \"AC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.47439461946487427, \"ref\": \"AC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.4437023997306824, \"ref\": \"AC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.48336899280548096, \"ref\": \"AC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.4569217562675476, \"ref\": \"AC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.49252569675445557, \"ref\": \"AC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5291972458362579, \"ref\": \"AC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5896462202072144, \"ref\": \"AC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6179554760456085, \"ref\": \"AC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6501660943031311, \"ref\": \"AC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.6912234723567963, \"ref\": \"AC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7021885216236115, \"ref\": \"AC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7472858428955078, \"ref\": \"AC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7412725389003754, \"ref\": \"AC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.7533613294363022, \"ref\": \"AC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.7507978230714798, \"ref\": \"AC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.25478007633592825, \"ref\": \"DoC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.37601234753038626, \"ref\": \"DoC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2736499531975005, \"ref\": \"DoC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.3948731048813079, \"ref\": \"DoC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.30944820482637625, \"ref\": \"DoC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.4117781146278594, \"ref\": \"DoC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3495906217804168, \"ref\": \"DoC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.431965730976126, \"ref\": \"DoC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.39838441450502615, \"ref\": \"DoC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.455291770290396, \"ref\": \"DoC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.43027403194811087, \"ref\": \"DoC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.4749359710922454, \"ref\": \"DoC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.42150899011995535, \"ref\": \"DoC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.48252912599947195, \"ref\": \"DoC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.4764598830452178, \"ref\": \"DoC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.527401111911795, \"ref\": \"DoC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5254330261459563, \"ref\": \"DoC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5570442302932952, \"ref\": \"DoC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5393907650222991, \"ref\": \"DoC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5555417164077971, \"ref\": \"DoC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5534442885627959, \"ref\": \"DoC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5656165703048919, \"ref\": \"DoC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.31300248939897757, \"ref\": \"DoC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.40977182228471976, \"ref\": \"DoC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3613584264030669, \"ref\": \"DoC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.4480102880707, \"ref\": \"DoC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.2983106597175811, \"ref\": \"DoC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.39878334839250784, \"ref\": \"DoC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3048092349281524, \"ref\": \"DoC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.4001230223884795, \"ref\": \"DoC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.31213542063142996, \"ref\": \"DoC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.407168470214865, \"ref\": \"DoC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5152374728431914, \"ref\": \"DoC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5742737277260039, \"ref\": \"DoC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5684255285968993, \"ref\": \"DoC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.6100591047516082, \"ref\": \"DoC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6126107795944427, \"ref\": \"DoC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6365662439575408, \"ref\": \"DoC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6107701881637786, \"ref\": \"DoC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6329204066505645, \"ref\": \"DoC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6261322124710296, \"ref\": \"DoC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.645864508937857, \"ref\": \"DoC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4041899069061492, \"ref\": \"DoC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.48253830511476736, \"ref\": \"DoC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.48391600687410574, \"ref\": \"DoC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.521179757904074, \"ref\": \"DoC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5048027559032653, \"ref\": \"DoC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5342702491989348, \"ref\": \"DoC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5066497250309203, \"ref\": \"DoC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5360972209682677, \"ref\": \"DoC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5175074561348174, \"ref\": \"DoC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5385503991356109, \"ref\": \"DoC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3347956164589141, \"ref\": \"DoC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.42347642023470145, \"ref\": \"DoC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.45908781130220633, \"ref\": \"DoC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5110880060901855, \"ref\": \"DoC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5222645922413085, \"ref\": \"DoC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5577421410789702, \"ref\": \"DoC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5494351013412688, \"ref\": \"DoC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.57157727320101, \"ref\": \"DoC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5770978554001067, \"ref\": \"DoC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5881301089039062, \"ref\": \"DoC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.3191156013717864, \"ref\": \"DoC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.42703702289964895, \"ref\": \"DoC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.37799843389894705, \"ref\": \"DoC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.46789886791612845, \"ref\": \"DoC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.45909740765001517, \"ref\": \"DoC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5231910272350524, \"ref\": \"DoC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5807598753681396, \"ref\": \"DoC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.6066006048431609, \"ref\": \"DoC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.6903157754650329, \"ref\": \"DoC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.7034267707576964, \"ref\": \"DoC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3476790412178252, \"ref\": \"DoC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.43129428465273123, \"ref\": \"DoC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.39102437336351614, \"ref\": \"DoC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.45894529659654837, \"ref\": \"DoC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4140046461334441, \"ref\": \"DoC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.46134891350176077, \"ref\": \"DoC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4316784365883086, \"ref\": \"DoC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.467599652599356, \"ref\": \"DoC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.4851227029075835, \"ref\": \"DoC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.5047466381302093, \"ref\": \"DoC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.35416980821993094, \"ref\": \"DoC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4499779566040252, \"ref\": \"DoC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.4092459305038665, \"ref\": \"DoC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.4730113967170928, \"ref\": \"DoC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.4703391416778777, \"ref\": \"DoC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.5183143242111419, \"ref\": \"DoC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6019852383842681, \"ref\": \"DoC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.6156576200237487, \"ref\": \"DoC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6917714400997375, \"ref\": \"DoC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6954350693931792, \"ref\": \"DoC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.282867453884146, \"ref\": \"DoC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.40428885061647635, \"ref\": \"DoC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.2938249929657195, \"ref\": \"DoC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4137363656273101, \"ref\": \"DoC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3020779116859649, \"ref\": \"DoC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.40751012403871756, \"ref\": \"DoC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.32784982759859305, \"ref\": \"DoC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.4300714953651641, \"ref\": \"DoC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.36423941690828543, \"ref\": \"DoC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.44709023077394705, \"ref\": \"DoC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.3258840068092559, \"ref\": \"DoC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.41767182190325003, \"ref\": \"DoC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.3675216062774871, \"ref\": \"DoC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.44187291700746756, \"ref\": \"DoC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.41755207617189627, \"ref\": \"DoC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4571352227440093, \"ref\": \"DoC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4568595512619231, \"ref\": \"DoC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4864657743683074, \"ref\": \"DoC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.48963197309877615, \"ref\": \"DoC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.515894524644873, \"ref\": \"DoC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.28539749224092703, \"ref\": \"DoC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.39791061718370657, \"ref\": \"DoC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.2892430051079009, \"ref\": \"DoC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.3997861965408538, \"ref\": \"DoC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.31611802418138724, \"ref\": \"DoC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4133042319526885, \"ref\": \"DoC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3341787083854888, \"ref\": \"DoC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.42232986528780203, \"ref\": \"DoC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.3567478879204009, \"ref\": \"DoC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.4309419019928191, \"ref\": \"DoC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.3654974921455596, \"ref\": \"DoC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4236716850509856, \"ref\": \"DoC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.38517590601351004, \"ref\": \"DoC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4186173899879668, \"ref\": \"DoC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3032597525825713, \"ref\": \"DoC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3969195111503814, \"ref\": \"DoC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.3582769854774688, \"ref\": \"DoC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.41004046041872244, \"ref\": \"DoC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.32259669144060354, \"ref\": \"DoC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.35307773191835623, \"ref\": \"DoC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.3205645306816314, \"ref\": \"DoC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.43541070063020926, \"ref\": \"DoC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.38760884840395193, \"ref\": \"DoC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.46107532818224173, \"ref\": \"DoC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.454571567367575, \"ref\": \"DoC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5039133651962493, \"ref\": \"DoC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5700780375709746, \"ref\": \"DoC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.6079933269729827, \"ref\": \"DoC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6565031631698821, \"ref\": \"DoC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6694191022625182, \"ref\": \"DoC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.3852731211891387, \"ref\": \"DoC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4630619509926055, \"ref\": \"DoC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.4740274770965789, \"ref\": \"DoC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5168169959297393, \"ref\": \"DoC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.4683395846595977, \"ref\": \"DoC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.483430050205252, \"ref\": \"DoC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.4854989274254058, \"ref\": \"DoC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.49219443638231497, \"ref\": \"DoC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5096112414112304, \"ref\": \"DoC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5314954741707061, \"ref\": \"DoC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.2713861091842864, \"ref\": \"DoC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.38857033092882376, \"ref\": \"DoC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.31489463884737234, \"ref\": \"DoC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.41490115959551077, \"ref\": \"DoC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.349334739040396, \"ref\": \"DoC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.43905081589128714, \"ref\": \"DoC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.38125868875887137, \"ref\": \"DoC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.4583234413376067, \"ref\": \"DoC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.4177452548256133, \"ref\": \"DoC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.47525670368578177, \"ref\": \"DoC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.30716063816454153, \"ref\": \"DoC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4223771317711089, \"ref\": \"DoC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.33055623609926443, \"ref\": \"DoC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.43494733412172537, \"ref\": \"DoC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.4123702867737029, \"ref\": \"DoC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.4723729117622588, \"ref\": \"DoC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.45980175573732596, \"ref\": \"DoC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.511279605220816, \"ref\": \"DoC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5234421118011687, \"ref\": \"DoC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5618473513832305, \"ref\": \"DoC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.36553730804826956, \"ref\": \"DoC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.4470659120788787, \"ref\": \"DoC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.394831143211386, \"ref\": \"DoC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.46021690208818655, \"ref\": \"DoC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.42340614635851126, \"ref\": \"DoC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4723102076759551, \"ref\": \"DoC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.4416179879417632, \"ref\": \"DoC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.4812845810165618, \"ref\": \"DoC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.45483734447862845, \"ref\": \"DoC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.4904412849655364, \"ref\": \"DoC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5271128340473388, \"ref\": \"DoC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5875618084182952, \"ref\": \"DoC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6158710642566894, \"ref\": \"DoC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6480816825142119, \"ref\": \"DoC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.6891390605678771, \"ref\": \"DoC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7001041098346923, \"ref\": \"DoC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7452014311065887, \"ref\": \"DoC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.7391881271114562, \"ref\": \"DoC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.751276917647383, \"ref\": \"DoC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.7487134112825606, \"ref\": \"DoC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.25716009323634914, \"ref\": \"IM\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.3643117923245659, \"ref\": \"IM\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.27182131298769163, \"ref\": \"IM\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.3826233899218616, \"ref\": \"IM\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3052949516099641, \"ref\": \"IM\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3964088893836726, \"ref\": \"IM\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3406618501919695, \"ref\": \"IM\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.4138902475123467, \"ref\": \"IM\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.3854842531279785, \"ref\": \"IM\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.4367357190812696, \"ref\": \"IM\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.4125669341295911, \"ref\": \"IM\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.45267069600806953, \"ref\": \"IM\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.40479085534949977, \"ref\": \"IM\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4600789524397767, \"ref\": \"IM\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.4533133858895976, \"ref\": \"IM\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.498720208925473, \"ref\": \"IM\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.49690618418552823, \"ref\": \"IM\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.5260576669874083, \"ref\": \"IM\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5080775942660181, \"ref\": \"IM\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.5223313415214244, \"ref\": \"IM\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.5229041568037729, \"ref\": \"IM\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.532975550990546, \"ref\": \"IM\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.30975979444181934, \"ref\": \"IM\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.3949540276289484, \"ref\": \"IM\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3520658448179034, \"ref\": \"IM\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.4300396907195273, \"ref\": \"IM\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.29465649540879535, \"ref\": \"IM\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3856943855579513, \"ref\": \"IM\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.29982664132490267, \"ref\": \"IM\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.38524739675926933, \"ref\": \"IM\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.30712604014804423, \"ref\": \"IM\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3920936183530447, \"ref\": \"IM\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.4889361158242328, \"ref\": \"IM\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.540145261057588, \"ref\": \"IM\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5369614448016979, \"ref\": \"IM\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.5719861171290961, \"ref\": \"IM\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.5718427099146223, \"ref\": \"IM\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.5938340905010482, \"ref\": \"IM\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.5704443877149948, \"ref\": \"IM\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.5928452284525466, \"ref\": \"IM\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.5862072010053286, \"ref\": \"IM\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.6026192581705492, \"ref\": \"IM\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.3901240999285097, \"ref\": \"IM\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4610875450067208, \"ref\": \"IM\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.4608745991327776, \"ref\": \"IM\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.49368194808439203, \"ref\": \"IM\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.4804122786628471, \"ref\": \"IM\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.5047439052859292, \"ref\": \"IM\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.48116743859050437, \"ref\": \"IM\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.5067523116064665, \"ref\": \"IM\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.4886822288817799, \"ref\": \"IM\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.5078763396893868, \"ref\": \"IM\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3293204447827015, \"ref\": \"IM\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.4088845564443362, \"ref\": \"IM\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.438473889453069, \"ref\": \"IM\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.48367390662263055, \"ref\": \"IM\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.4946016096776157, \"ref\": \"IM\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.5252630438382432, \"ref\": \"IM\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5182032393039437, \"ref\": \"IM\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.5381867237072835, \"ref\": \"IM\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.541928524407825, \"ref\": \"IM\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.5528998763739983, \"ref\": \"IM\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.3143797472483836, \"ref\": \"IM\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.41168458914717665, \"ref\": \"IM\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.3658080917081823, \"ref\": \"IM\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4487482438560305, \"ref\": \"IM\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.43940186202326237, \"ref\": \"IM\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.4972630123910068, \"ref\": \"IM\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5458186227391473, \"ref\": \"IM\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.5702683893780462, \"ref\": \"IM\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.6414839732423757, \"ref\": \"IM\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.6523034787808488, \"ref\": \"IM\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3398797068216083, \"ref\": \"IM\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.41572461933588944, \"ref\": \"IM\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.37838694548818463, \"ref\": \"IM\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.439669506975752, \"ref\": \"IM\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.40022765365115565, \"ref\": \"IM\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4419794676224824, \"ref\": \"IM\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4151348150381263, \"ref\": \"IM\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4481839958018755, \"ref\": \"IM\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.4627910489114939, \"ref\": \"IM\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.47963008404083407, \"ref\": \"IM\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.3451654167036663, \"ref\": \"IM\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4329143046262258, \"ref\": \"IM\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.3949109698169252, \"ref\": \"IM\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.45220623482717803, \"ref\": \"IM\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.44918823929227125, \"ref\": \"IM\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.49216046651164946, \"ref\": \"IM\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.5647013110481147, \"ref\": \"IM\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.5769308717676249, \"ref\": \"IM\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6438810170586922, \"ref\": \"IM\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.6440985781824723, \"ref\": \"IM\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2812951666750573, \"ref\": \"IM\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.38851783763559933, \"ref\": \"IM\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.29204147546402914, \"ref\": \"IM\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.39978539077619546, \"ref\": \"IM\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.29891642990861267, \"ref\": \"IM\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3940852340287673, \"ref\": \"IM\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.32129162233255026, \"ref\": \"IM\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.41550147854997765, \"ref\": \"IM\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.35417964144596426, \"ref\": \"IM\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.4278007052298811, \"ref\": \"IM\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.3191185747731238, \"ref\": \"IM\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4030042191214347, \"ref\": \"IM\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.35922184159745363, \"ref\": \"IM\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.42403336155061244, \"ref\": \"IM\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4024443794819299, \"ref\": \"IM\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4375153308728289, \"ref\": \"IM\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.4357319882783123, \"ref\": \"IM\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.46188807410234434, \"ref\": \"IM\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.4665593065029109, \"ref\": \"IM\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.4909933174437796, \"ref\": \"IM\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.2830214472070959, \"ref\": \"IM\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.3833011314011383, \"ref\": \"IM\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.2878841711818829, \"ref\": \"IM\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.3857791235487359, \"ref\": \"IM\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.31227537791948823, \"ref\": \"IM\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3963729026492828, \"ref\": \"IM\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3275792194138023, \"ref\": \"IM\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.405794191264082, \"ref\": \"IM\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.34975010797886197, \"ref\": \"IM\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.4160862365918566, \"ref\": \"IM\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.35659357460205066, \"ref\": \"IM\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4084402058449864, \"ref\": \"IM\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.3744270390501737, \"ref\": \"IM\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4033629735746834, \"ref\": \"IM\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.29841258677748483, \"ref\": \"IM\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3837169055614543, \"ref\": \"IM\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.3478406283335359, \"ref\": \"IM\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.3954517554810635, \"ref\": \"IM\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3170442460872074, \"ref\": \"IM\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.34402138711566077, \"ref\": \"IM\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.3154025518496011, \"ref\": \"IM\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.41867182294924266, \"ref\": \"IM\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.37483989364719894, \"ref\": \"IM\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.44158000144083553, \"ref\": \"IM\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.4339121256827645, \"ref\": \"IM\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.4811957942342181, \"ref\": \"IM\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5374856038540184, \"ref\": \"IM\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.5697009084137358, \"ref\": \"IM\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6107221892042698, \"ref\": \"IM\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.6196490048286629, \"ref\": \"IM\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.37343702005236146, \"ref\": \"IM\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4436289551105236, \"ref\": \"IM\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.4520547164481403, \"ref\": \"IM\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.4897826323338419, \"ref\": \"IM\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.44820420981297326, \"ref\": \"IM\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.46186490992634643, \"ref\": \"IM\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.4615258067213752, \"ref\": \"IM\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.47068873154685875, \"ref\": \"IM\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.48335133699722166, \"ref\": \"IM\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.5038971810054611, \"ref\": \"IM\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27175339078601146, \"ref\": \"IM\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.3782692194373669, \"ref\": \"IM\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3089444184783502, \"ref\": \"IM\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.4014104107948506, \"ref\": \"IM\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3428077407036074, \"ref\": \"IM\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.42272245503620054, \"ref\": \"IM\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.3694104135647115, \"ref\": \"IM\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.440217105003713, \"ref\": \"IM\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.40317434799092056, \"ref\": \"IM\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.45466701116287067, \"ref\": \"IM\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.30196351072099836, \"ref\": \"IM\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4064889752079379, \"ref\": \"IM\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3247973093394235, \"ref\": \"IM\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.418093023156499, \"ref\": \"IM\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.39971511343818733, \"ref\": \"IM\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.45094646557801865, \"ref\": \"IM\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.4389499656040299, \"ref\": \"IM\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.48644267857188306, \"ref\": \"IM\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.49575090273982625, \"ref\": \"IM\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.5298598071116044, \"ref\": \"IM\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.355278323567524, \"ref\": \"IM\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.42821631051119935, \"ref\": \"IM\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.3838473812039347, \"ref\": \"IM\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.44094649112175865, \"ref\": \"IM\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4069917761661508, \"ref\": \"IM\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.451617232981422, \"ref\": \"IM\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.42351477249902725, \"ref\": \"IM\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.45902033097740547, \"ref\": \"IM\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.43545197416707526, \"ref\": \"IM\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.4686720691059, \"ref\": \"IM\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.4999234612043285, \"ref\": \"IM\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.549576354385005, \"ref\": \"IM\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.5755587824465013, \"ref\": \"IM\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6045315784505358, \"ref\": \"IM\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.6382958464483546, \"ref\": \"IM\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.647699139734954, \"ref\": \"IM\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.6858710254014728, \"ref\": \"IM\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.6812393365975284, \"ref\": \"IM\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.6905633722476795, \"ref\": \"IM\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.6878350822755324, \"ref\": \"IM\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.26, \"ref\": \"ATC-MC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.4052941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2817647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.4470588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.32823529411764707, \"ref\": \"ATC-MC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.46705882352941175, \"ref\": \"ATC-MC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3835294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.49823529411764705, \"ref\": \"ATC-MC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.46647058823529414, \"ref\": \"ATC-MC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5323529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5005882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5629411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.4970588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.5682352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.5788235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6429411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6405882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6935294117647058, \"ref\": \"ATC-MC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.6564705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.69, \"ref\": \"ATC-MC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.6729411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.6982352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.32588235294117646, \"ref\": \"ATC-MC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.46352941176470586, \"ref\": \"ATC-MC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.40647058823529414, \"ref\": \"ATC-MC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.5258823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3111764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.43529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3264705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.44, \"ref\": \"ATC-MC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3311764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.45294117647058824, \"ref\": \"ATC-MC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.63, \"ref\": \"ATC-MC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.7276470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7194117647058823, \"ref\": \"ATC-MC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.778235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.7841176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8152941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.78, \"ref\": \"ATC-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8147058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8017647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.841764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4611764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.5782352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.5764705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6276470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6141176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6558823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6141176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6564705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6352941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6652941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.36, \"ref\": \"ATC-MC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.47823529411764704, \"ref\": \"ATC-MC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5429411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.6152941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6370588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6882352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.6741176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7123529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7158823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7382352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.34058823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.4929411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4235294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.5564705882352942, \"ref\": \"ATC-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5358823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6523529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7558823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7911764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9364705882352942, \"ref\": \"ATC-MC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9529411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.37529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.4958823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.43823529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.538235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.4711764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5305882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.4929411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5394117647058824, \"ref\": \"ATC-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.5852941176470589, \"ref\": \"ATC-MC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6047058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.38823529411764707, \"ref\": \"ATC-MC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5176470588235295, \"ref\": \"ATC-MC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.45647058823529413, \"ref\": \"ATC-MC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.571764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6417647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.7911764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.8158823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9352941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2888235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4476470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.3076470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4717647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3088235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4641176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.34941176470588237, \"ref\": \"ATC-MC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.49058823529411766, \"ref\": \"ATC-MC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.4, \"ref\": \"ATC-MC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.5188235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.34058823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.47705882352941176, \"ref\": \"ATC-MC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4023529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5123529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.47352941176470587, \"ref\": \"ATC-MC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5141176470588236, \"ref\": \"ATC-MC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.5358823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.5647058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.5835294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.6376470588235295, \"ref\": \"ATC-MC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.29411764705882354, \"ref\": \"ATC-MC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.4411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.29058823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.43941176470588234, \"ref\": \"ATC-MC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3323529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4547058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.36, \"ref\": \"ATC-MC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.47294117647058825, \"ref\": \"ATC-MC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.3947058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.49529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.3982352941176471, \"ref\": \"ATC-MC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4752941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4294117647058823, \"ref\": \"ATC-MC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.44941176470588234, \"ref\": \"ATC-MC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.31176470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.43529411764705883, \"ref\": \"ATC-MC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.38294117647058823, \"ref\": \"ATC-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.46352941176470586, \"ref\": \"ATC-MC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.34058823529411764, \"ref\": \"ATC-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3864705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.3341176470588235, \"ref\": \"ATC-MC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.4976470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4370588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.5417647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5364705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6205882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7329411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7858823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8705882352941177, \"ref\": \"ATC-MC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8858823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4323529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.5435294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5570588235294117, \"ref\": \"ATC-MC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.62, \"ref\": \"ATC-MC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.5576470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.5788235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.5752941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6011764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6223529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6535294117647059, \"ref\": \"ATC-MC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27647058823529413, \"ref\": \"ATC-MC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.42, \"ref\": \"ATC-MC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.32823529411764707, \"ref\": \"ATC-MC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.46294117647058824, \"ref\": \"ATC-MC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.37470588235294117, \"ref\": \"ATC-MC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.508235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.42470588235294116, \"ref\": \"ATC-MC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5376470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.4858823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.57, \"ref\": \"ATC-MC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.32235294117647056, \"ref\": \"ATC-MC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4788235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3411764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.49470588235294116, \"ref\": \"ATC-MC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.47705882352941176, \"ref\": \"ATC-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5588235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.5447058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.6329411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6552941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7176470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.4023529411764706, \"ref\": \"ATC-MC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5152941176470588, \"ref\": \"ATC-MC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4464705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5388235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5047058823529412, \"ref\": \"ATC-MC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5511764705882353, \"ref\": \"ATC-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5276470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5776470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5364705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.59, \"ref\": \"ATC-MC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.65, \"ref\": \"ATC-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.7517647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.7870588235294118, \"ref\": \"ATC-MC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.8358823529411765, \"ref\": \"ATC-MC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.8929411764705882, \"ref\": \"ATC-MC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9117647058823529, \"ref\": \"ATC-MC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9664705882352941, \"ref\": \"ATC-MC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9576470588235294, \"ref\": \"ATC-MC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.97, \"ref\": \"ATC-MC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9588235294117647, \"ref\": \"ATC-MC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.25470588235294117, \"ref\": \"ATC-NE\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.3982352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2847058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.4323529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.34058823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.48411764705882354, \"ref\": \"ATC-NE\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.4123529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.5211764705882352, \"ref\": \"ATC-NE\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.48176470588235293, \"ref\": \"ATC-NE\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5641176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5364705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5935294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.5223529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.601764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6176470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6905882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6964705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.7458823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.7247058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.7488235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7376470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7741176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.32941176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.48, \"ref\": \"ATC-NE\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.41411764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.5252941176470588, \"ref\": \"ATC-NE\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3164705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.43529411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.32588235294117646, \"ref\": \"ATC-NE\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.43529411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.33941176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.45529411764705885, \"ref\": \"ATC-NE\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.6905882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.7752941176470588, \"ref\": \"ATC-NE\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7705882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.8405882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8352941176470589, \"ref\": \"ATC-NE\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8794117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8376470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8764705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8629411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8905882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.49411764705882355, \"ref\": \"ATC-NE\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.601764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6294117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6835294117647058, \"ref\": \"ATC-NE\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6735294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.7229411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6758823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.7247058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6905882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.7447058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.36941176470588233, \"ref\": \"ATC-NE\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.48705882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5929411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.658235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6935294117647058, \"ref\": \"ATC-NE\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.75, \"ref\": \"ATC-NE\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7364705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7764705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7794117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.8094117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.34941176470588237, \"ref\": \"ATC-NE\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.5088235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.44588235294117645, \"ref\": \"ATC-NE\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.5835294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5935294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6923529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.8023529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.8464705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9594117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9711764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3876470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.5011764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.45529411764705885, \"ref\": \"ATC-NE\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.5535294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.48, \"ref\": \"ATC-NE\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5358823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5041176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5529411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6082352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6276470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4088235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5323529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.49058823529411766, \"ref\": \"ATC-NE\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5864705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6111764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6923529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.841764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.8711764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9688235294117648, \"ref\": \"ATC-NE\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9694117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.30176470588235293, \"ref\": \"ATC-NE\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.45294117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.30941176470588233, \"ref\": \"ATC-NE\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4711764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.31941176470588234, \"ref\": \"ATC-NE\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4641176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.36176470588235293, \"ref\": \"ATC-NE\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.5058823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.43176470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.5311764705882352, \"ref\": \"ATC-NE\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.34294117647058825, \"ref\": \"ATC-NE\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4811764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4076470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5247058823529411, \"ref\": \"ATC-NE\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.4988235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5388235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.5605882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6111764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.63, \"ref\": \"ATC-NE\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.6705882352941176, \"ref\": \"ATC-NE\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.29823529411764704, \"ref\": \"ATC-NE\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.44176470588235295, \"ref\": \"ATC-NE\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.3029411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.43941176470588234, \"ref\": \"ATC-NE\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.33941176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4723529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3652941176470588, \"ref\": \"ATC-NE\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.48823529411764705, \"ref\": \"ATC-NE\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.39705882352941174, \"ref\": \"ATC-NE\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.5, \"ref\": \"ATC-NE\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.39235294117647057, \"ref\": \"ATC-NE\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4764705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.42705882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.4611764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.31588235294117645, \"ref\": \"ATC-NE\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.4335294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.39705882352941174, \"ref\": \"ATC-NE\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.48823529411764705, \"ref\": \"ATC-NE\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.3488235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.40058823529411763, \"ref\": \"ATC-NE\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.35352941176470587, \"ref\": \"ATC-NE\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.5164705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4682352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.5688235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5723529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6541176470588236, \"ref\": \"ATC-NE\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.78, \"ref\": \"ATC-NE\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.8370588235294117, \"ref\": \"ATC-NE\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.9023529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.9229411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4582352941176471, \"ref\": \"ATC-NE\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.5811764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6129411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6841176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6047058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6064705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6188235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6329411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6888235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.72, \"ref\": \"ATC-NE\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.28823529411764703, \"ref\": \"ATC-NE\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.43117647058823527, \"ref\": \"ATC-NE\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3388235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.47352941176470587, \"ref\": \"ATC-NE\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3941176470588235, \"ref\": \"ATC-NE\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.5176470588235295, \"ref\": \"ATC-NE\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.44588235294117645, \"ref\": \"ATC-NE\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5547058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5135294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5994117647058823, \"ref\": \"ATC-NE\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.3311764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.49176470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3623529411764706, \"ref\": \"ATC-NE\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.5135294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5105882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5935294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.5888235294117647, \"ref\": \"ATC-NE\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.6611764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6876470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7458823529411764, \"ref\": \"ATC-NE\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.4335294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5464705882352942, \"ref\": \"ATC-NE\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4747058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5658823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5135294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5858823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5411764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.6064705882352941, \"ref\": \"ATC-NE\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5629411764705883, \"ref\": \"ATC-NE\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.6229411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.7094117647058824, \"ref\": \"ATC-NE\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.8058823529411765, \"ref\": \"ATC-NE\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.851764705882353, \"ref\": \"ATC-NE\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.8905882352941177, \"ref\": \"ATC-NE\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9364705882352942, \"ref\": \"ATC-NE\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9547058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9835294117647059, \"ref\": \"ATC-NE\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9829411764705882, \"ref\": \"ATC-NE\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9847058823529412, \"ref\": \"ATC-NE\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9776470588235294, \"ref\": \"ATC-NE\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.2597547769546509, \"ref\": \"COT\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.40150293707847595, \"ref\": \"COT\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.28364914655685425, \"ref\": \"COT\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.4300719201564789, \"ref\": \"COT\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.32408615946769714, \"ref\": \"COT\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.4520876407623291, \"ref\": \"COT\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3725247383117676, \"ref\": \"COT\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.4767075777053833, \"ref\": \"COT\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.42994654178619385, \"ref\": \"COT\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5057112574577332, \"ref\": \"COT\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.47961851954460144, \"ref\": \"COT\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5349220633506775, \"ref\": \"COT\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.48512211441993713, \"ref\": \"COT\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.5646870136260986, \"ref\": \"COT\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.5528350472450256, \"ref\": \"COT\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6169809699058533, \"ref\": \"COT\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6313156485557556, \"ref\": \"COT\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.6747012734413147, \"ref\": \"COT\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.6857916116714478, \"ref\": \"COT\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.7098894119262695, \"ref\": \"COT\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7212618589401245, \"ref\": \"COT\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.7345565557479858, \"ref\": \"COT\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.3303042948246002, \"ref\": \"COT\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.4544151723384857, \"ref\": \"COT\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.3745395541191101, \"ref\": \"COT\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.48047712445259094, \"ref\": \"COT\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.31732824444770813, \"ref\": \"COT\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.44845402240753174, \"ref\": \"COT\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3231368064880371, \"ref\": \"COT\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.45146453380584717, \"ref\": \"COT\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.33568498492240906, \"ref\": \"COT\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.46480876207351685, \"ref\": \"COT\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.5680691599845886, \"ref\": \"COT\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.6328473687171936, \"ref\": \"COT\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.627562940120697, \"ref\": \"COT\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.6732017993927002, \"ref\": \"COT\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.6784297227859497, \"ref\": \"COT\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.7040827870368958, \"ref\": \"COT\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.6858649849891663, \"ref\": \"COT\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.7084375619888306, \"ref\": \"COT\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.7263993620872498, \"ref\": \"COT\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.7426605820655823, \"ref\": \"COT\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.4415108263492584, \"ref\": \"COT\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.5454940795898438, \"ref\": \"COT\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.5707955360412598, \"ref\": \"COT\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.6229733228683472, \"ref\": \"COT\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6318899393081665, \"ref\": \"COT\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.6640750169754028, \"ref\": \"COT\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.6426894068717957, \"ref\": \"COT\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.674493670463562, \"ref\": \"COT\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6763434410095215, \"ref\": \"COT\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.6965135335922241, \"ref\": \"COT\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3727335035800934, \"ref\": \"COT\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.48631203174591064, \"ref\": \"COT\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5319917798042297, \"ref\": \"COT\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5994735360145569, \"ref\": \"COT\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6178784370422363, \"ref\": \"COT\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.6650173664093018, \"ref\": \"COT\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.6698164343833923, \"ref\": \"COT\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7016424536705017, \"ref\": \"COT\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7333115339279175, \"ref\": \"COT\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.7459292411804199, \"ref\": \"COT\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.33300405740737915, \"ref\": \"COT\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.45920148491859436, \"ref\": \"COT\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.4486319422721863, \"ref\": \"COT\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.5513779520988464, \"ref\": \"COT\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.5765623450279236, \"ref\": \"COT\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6498664617538452, \"ref\": \"COT\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.6873120069503784, \"ref\": \"COT\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7187883257865906, \"ref\": \"COT\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.800870418548584, \"ref\": \"COT\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.8087755441665649, \"ref\": \"COT\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.3897415101528168, \"ref\": \"COT\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.500562310218811, \"ref\": \"COT\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.45413628220558167, \"ref\": \"COT\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.5459010601043701, \"ref\": \"COT\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5009185671806335, \"ref\": \"COT\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5743295550346375, \"ref\": \"COT\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5513011813163757, \"ref\": \"COT\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.6144309639930725, \"ref\": \"COT\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6340348720550537, \"ref\": \"COT\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.6710925698280334, \"ref\": \"COT\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4079698622226715, \"ref\": \"COT\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5276420712471008, \"ref\": \"COT\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5235734581947327, \"ref\": \"COT\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.6154480576515198, \"ref\": \"COT\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.5965194702148438, \"ref\": \"COT\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6553532481193542, \"ref\": \"COT\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.7092363834381104, \"ref\": \"COT\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.729812741279602, \"ref\": \"COT\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.8032971024513245, \"ref\": \"COT\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.804345428943634, \"ref\": \"COT\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2954219579696655, \"ref\": \"COT\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4414002597332001, \"ref\": \"COT\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.3071881830692291, \"ref\": \"COT\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.4489256739616394, \"ref\": \"COT\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3152823746204376, \"ref\": \"COT\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.4446273148059845, \"ref\": \"COT\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.34416335821151733, \"ref\": \"COT\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.46758735179901123, \"ref\": \"COT\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.38211050629615784, \"ref\": \"COT\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.48444661498069763, \"ref\": \"COT\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.3634728789329529, \"ref\": \"COT\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.4825882315635681, \"ref\": \"COT\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.42441093921661377, \"ref\": \"COT\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5224575996398926, \"ref\": \"COT\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.49816060066223145, \"ref\": \"COT\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5633591413497925, \"ref\": \"COT\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.563321590423584, \"ref\": \"COT\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6088371872901917, \"ref\": \"COT\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.5979713201522827, \"ref\": \"COT\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.635463535785675, \"ref\": \"COT\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.30407315492630005, \"ref\": \"COT\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.44590291380882263, \"ref\": \"COT\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.31269219517707825, \"ref\": \"COT\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.4507793188095093, \"ref\": \"COT\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.34457528591156006, \"ref\": \"COT\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.472085565328598, \"ref\": \"COT\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.3714539408683777, \"ref\": \"COT\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.48805585503578186, \"ref\": \"COT\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.3979353606700897, \"ref\": \"COT\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.5006052851676941, \"ref\": \"COT\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.4470289945602417, \"ref\": \"COT\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.5512992143630981, \"ref\": \"COT\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.5048344731330872, \"ref\": \"COT\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.576546847820282, \"ref\": \"COT\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.3447875380516052, \"ref\": \"COT\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.44300368428230286, \"ref\": \"COT\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.5448209643363953, \"ref\": \"COT\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.6030905842781067, \"ref\": \"COT\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.6298406720161438, \"ref\": \"COT\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.6805370450019836, \"ref\": \"COT\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.34143954515457153, \"ref\": \"COT\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.4669661819934845, \"ref\": \"COT\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.4635319709777832, \"ref\": \"COT\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.5615561008453369, \"ref\": \"COT\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.5719571709632874, \"ref\": \"COT\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6384527087211609, \"ref\": \"COT\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.6811544895172119, \"ref\": \"COT\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7167212963104248, \"ref\": \"COT\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.7504749298095703, \"ref\": \"COT\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.7662137150764465, \"ref\": \"COT\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.41457849740982056, \"ref\": \"COT\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.5301109552383423, \"ref\": \"COT\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.5549600124359131, \"ref\": \"COT\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6111229062080383, \"ref\": \"COT\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.5699336528778076, \"ref\": \"COT\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6131497025489807, \"ref\": \"COT\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6375501155853271, \"ref\": \"COT\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.6573466658592224, \"ref\": \"COT\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6619479060173035, \"ref\": \"COT\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.6760717630386353, \"ref\": \"COT\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.2796747088432312, \"ref\": \"COT\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.42657867074012756, \"ref\": \"COT\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.32875916361808777, \"ref\": \"COT\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.45736321806907654, \"ref\": \"COT\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.3838213384151459, \"ref\": \"COT\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.4992476999759674, \"ref\": \"COT\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.43477925658226013, \"ref\": \"COT\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5145454406738281, \"ref\": \"COT\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5038549304008484, \"ref\": \"COT\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5591875910758972, \"ref\": \"COT\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.32363075017929077, \"ref\": \"COT\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.4488810896873474, \"ref\": \"COT\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.3728671073913574, \"ref\": \"COT\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.4855291247367859, \"ref\": \"COT\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5132740139961243, \"ref\": \"COT\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.5926111340522766, \"ref\": \"COT\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.575835108757019, \"ref\": \"COT\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.638629674911499, \"ref\": \"COT\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6427764296531677, \"ref\": \"COT\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.6820104122161865, \"ref\": \"COT\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.41094791889190674, \"ref\": \"COT\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5120770335197449, \"ref\": \"COT\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4539673626422882, \"ref\": \"COT\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5366452932357788, \"ref\": \"COT\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.4920126497745514, \"ref\": \"COT\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5583893060684204, \"ref\": \"COT\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5154080390930176, \"ref\": \"COT\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5735103487968445, \"ref\": \"COT\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5407332181930542, \"ref\": \"COT\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5923134684562683, \"ref\": \"COT\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.5661094784736633, \"ref\": \"COT\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.6322148442268372, \"ref\": \"COT\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.6662365794181824, \"ref\": \"COT\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.701309323310852, \"ref\": \"COT\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7670374512672424, \"ref\": \"COT\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.7750825881958008, \"ref\": \"COT\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.8464444279670715, \"ref\": \"COT\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.8396369814872742, \"ref\": \"COT\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.8611334562301636, \"ref\": \"COT\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.8551613688468933, \"ref\": \"COT\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.2605882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.7358823418617249, \"error\": 0.26411765813827515, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"clean\", \"corruption level\": 0, \"metric\": 0.43058823529411766, \"ref\": \"COTT-MC\", \"acc\": 0.4005882143974304, \"error\": 0.5994117856025696, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.2823529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.7111764550209045, \"error\": 0.28882354497909546, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 1, \"metric\": 0.46941176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3699999749660492, \"error\": 0.6300000250339508, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.3288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.6458823084831238, \"error\": 0.3541176915168762, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 2, \"metric\": 0.48823529411764705, \"ref\": \"COTT-MC\", \"acc\": 0.3529411554336548, \"error\": 0.6470588445663452, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.3876470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.5811764597892761, \"error\": 0.4188235402107239, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 3, \"metric\": 0.52, \"ref\": \"COTT-MC\", \"acc\": 0.31823527812957764, \"error\": 0.6817647218704224, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.47705882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.5164705514907837, \"error\": 0.4835294485092163, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 4, \"metric\": 0.5541176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.2982352674007416, \"error\": 0.7017647325992584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5305882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.4476470351219177, \"error\": 0.5523529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"brightness\", \"corruption level\": 5, \"metric\": 0.5947058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.26411762833595276, \"error\": 0.7358823716640472, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.538235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.5052940845489502, \"error\": 0.4947059154510498, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 1, \"metric\": 0.6288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.2588235139846802, \"error\": 0.7411764860153198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.6329411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.4317646920681, \"error\": 0.5682353079319, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 2, \"metric\": 0.7058823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.7188235294117648, \"ref\": \"COTT-MC\", \"acc\": 0.32235291600227356, \"error\": 0.6776470839977264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 3, \"metric\": 0.7835294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.1899999976158142, \"error\": 0.8100000023841858, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.788235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 4, \"metric\": 0.8264705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.1464705765247345, \"error\": 0.8535294234752655, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.8258823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.20999999344348907, \"error\": 0.7900000065565109, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"defocus_blur\", \"corruption level\": 5, \"metric\": 0.851764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.3264705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.6670588254928589, \"error\": 0.3329411745071411, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 1, \"metric\": 0.4929411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.33764705061912537, \"error\": 0.6623529493808746, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.40705882352941175, \"ref\": \"COTT-MC\", \"acc\": 0.5852940678596497, \"error\": 0.41470593214035034, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 2, \"metric\": 0.5417647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.30176469683647156, \"error\": 0.6982353031635284, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.3123529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.6782352924346924, \"error\": 0.3217647075653076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 3, \"metric\": 0.4682352941176471, \"ref\": \"COTT-MC\", \"acc\": 0.36941173672676086, \"error\": 0.6305882632732391, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.3270588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.6752941012382507, \"error\": 0.32470589876174927, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 4, \"metric\": 0.4752941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.3664705753326416, \"error\": 0.6335294246673584, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.3376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6617646813392639, \"error\": 0.3382353186607361, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"elastic_transform\", \"corruption level\": 5, \"metric\": 0.5094117647058823, \"ref\": \"COTT-MC\", \"acc\": 0.3435294032096863, \"error\": 0.6564705967903137, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.6335294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.409411758184433, \"error\": 0.590588241815567, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 1, \"metric\": 0.7376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.22117646038532257, \"error\": 0.7788235396146774, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7235294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.3399999737739563, \"error\": 0.6600000262260437, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 2, \"metric\": 0.7811764705882352, \"ref\": \"COTT-MC\", \"acc\": 0.18705882132053375, \"error\": 0.8129411786794662, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.7888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.26764705777168274, \"error\": 0.7323529422283173, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 3, \"metric\": 0.8170588235294117, \"ref\": \"COTT-MC\", \"acc\": 0.15941175818443298, \"error\": 0.840588241815567, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.7805882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.25294116139411926, \"error\": 0.7470588386058807, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 4, \"metric\": 0.8147058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.15352940559387207, \"error\": 0.8464705944061279, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8164705882352942, \"ref\": \"COTT-MC\", \"acc\": 0.18294116854667664, \"error\": 0.8170588314533234, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"fog\", \"corruption level\": 5, \"metric\": 0.8511764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.11176469922065735, \"error\": 0.8882353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.48705882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.5335294008255005, \"error\": 0.4664705991744995, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 1, \"metric\": 0.6423529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.2952941060066223, \"error\": 0.7047058939933777, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.65, \"ref\": \"COTT-MC\", \"acc\": 0.36705881357192993, \"error\": 0.6329411864280701, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 2, \"metric\": 0.7188235294117648, \"ref\": \"COTT-MC\", \"acc\": 0.20705881714820862, \"error\": 0.7929411828517914, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.7188235294117648, \"ref\": \"COTT-MC\", \"acc\": 0.2776470482349396, \"error\": 0.7223529517650604, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 3, \"metric\": 0.7658823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.17352940142154694, \"error\": 0.8264705985784531, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.7358823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 4, \"metric\": 0.7776470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.1652941107749939, \"error\": 0.8347058892250061, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.7705882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.2441176325082779, \"error\": 0.7558823674917221, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"frost\", \"corruption level\": 5, \"metric\": 0.7988235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.3735294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.6182352900505066, \"error\": 0.3817647099494934, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 1, \"metric\": 0.5229411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.31117644906044006, \"error\": 0.6888235509395599, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.5982352941176471, \"ref\": \"COTT-MC\", \"acc\": 0.45588234066963196, \"error\": 0.544117659330368, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 2, \"metric\": 0.678235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.24764704704284668, \"error\": 0.7523529529571533, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.7047058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.3517646789550781, \"error\": 0.6482353210449219, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 3, \"metric\": 0.77, \"ref\": \"COTT-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.7723529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.2876470386981964, \"error\": 0.7123529613018036, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 4, \"metric\": 0.8152941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.16235293447971344, \"error\": 0.8376470655202866, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.8458823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.20352940261363983, \"error\": 0.7964705973863602, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_blur\", \"corruption level\": 5, \"metric\": 0.87, \"ref\": \"COTT-MC\", \"acc\": 0.13058823347091675, \"error\": 0.8694117665290833, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.34294117647058825, \"ref\": \"COTT-MC\", \"acc\": 0.6605882048606873, \"error\": 0.33941179513931274, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 1, \"metric\": 0.4970588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.3476470410823822, \"error\": 0.6523529589176178, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.49, \"ref\": \"COTT-MC\", \"acc\": 0.5247058868408203, \"error\": 0.4752941131591797, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 2, \"metric\": 0.6258823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.27941176295280457, \"error\": 0.7205882370471954, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.6211764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 3, \"metric\": 0.7341176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.19882352650165558, \"error\": 0.8011764734983444, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.7741176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.23588234186172485, \"error\": 0.7641176581382751, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 4, \"metric\": 0.8076470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.11999999731779099, \"error\": 0.880000002682209, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9364705882352942, \"ref\": \"COTT-MC\", \"acc\": 0.1241176426410675, \"error\": 0.8758823573589325, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"gaussian_noise\", \"corruption level\": 5, \"metric\": 0.9529411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.08294117450714111, \"error\": 0.9170588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.38941176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.5941176414489746, \"error\": 0.4058823585510254, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 1, \"metric\": 0.5435294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.3058823347091675, \"error\": 0.6941176652908325, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.47705882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.5317646861076355, \"error\": 0.4682353138923645, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 2, \"metric\": 0.6029411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.27705880999565125, \"error\": 0.7229411900043488, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.5288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.4582352638244629, \"error\": 0.5417647361755371, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 3, \"metric\": 0.6158823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.23764705657958984, \"error\": 0.7623529434204102, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.5911764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.3888235092163086, \"error\": 0.6111764907836914, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 4, \"metric\": 0.6647058823529411, \"ref\": \"COTT-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.7194117647058823, \"ref\": \"COTT-MC\", \"acc\": 0.3011764585971832, \"error\": 0.6988235414028168, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"glass_blur\", \"corruption level\": 5, \"metric\": 0.7570588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.15529410541057587, \"error\": 0.8447058945894241, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.4376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.5729411244392395, \"error\": 0.4270588755607605, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 1, \"metric\": 0.5882352941176471, \"ref\": \"COTT-MC\", \"acc\": 0.29764705896377563, \"error\": 0.7023529410362244, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.5564705882352942, \"ref\": \"COTT-MC\", \"acc\": 0.44058820605278015, \"error\": 0.5594117939472198, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 2, \"metric\": 0.6788235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.23411764204502106, \"error\": 0.7658823579549789, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.6588235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.3494117558002472, \"error\": 0.6505882441997528, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 3, \"metric\": 0.7364705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.18647058308124542, \"error\": 0.8135294169187546, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.7941176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.20823527872562408, \"error\": 0.7917647212743759, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 4, \"metric\": 0.8305882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.12823529541492462, \"error\": 0.8717647045850754, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.941764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.12529411911964417, \"error\": 0.8747058808803558, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"impulse_noise\", \"corruption level\": 5, \"metric\": 0.9352941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.08411764353513718, \"error\": 0.9158823564648628, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.2888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.6958823204040527, \"error\": 0.30411767959594727, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 1, \"metric\": 0.4711764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.36352938413619995, \"error\": 0.6364706158638, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.3076470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 2, \"metric\": 0.49058823529411766, \"ref\": \"COTT-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.3111764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.6794117093086243, \"error\": 0.32058829069137573, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 3, \"metric\": 0.48411764705882354, \"ref\": \"COTT-MC\", \"acc\": 0.35647058486938477, \"error\": 0.6435294151306152, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.3517647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.6541176438331604, \"error\": 0.3458823561668396, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 4, \"metric\": 0.5076470588235295, \"ref\": \"COTT-MC\", \"acc\": 0.3329411745071411, \"error\": 0.6670588254928589, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.40176470588235297, \"ref\": \"COTT-MC\", \"acc\": 0.5923529267311096, \"error\": 0.4076470732688904, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"jpeg_compression\", \"corruption level\": 5, \"metric\": 0.5258823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.317058801651001, \"error\": 0.682941198348999, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.36470588235294116, \"ref\": \"COTT-MC\", \"acc\": 0.6247058510780334, \"error\": 0.37529414892196655, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 1, \"metric\": 0.5241176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3199999928474426, \"error\": 0.6800000071525574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.4376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.5470588207244873, \"error\": 0.4529411792755127, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 2, \"metric\": 0.5723529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.270588219165802, \"error\": 0.729411780834198, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.5405882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.4599999785423279, \"error\": 0.5400000214576721, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 3, \"metric\": 0.6152941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.2347058802843094, \"error\": 0.7652941197156906, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6270588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.3752940893173218, \"error\": 0.6247059106826782, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 4, \"metric\": 0.6829411764705883, \"ref\": \"COTT-MC\", \"acc\": 0.21470586955547333, \"error\": 0.7852941304445267, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.6694117647058824, \"ref\": \"COTT-MC\", \"acc\": 0.32764706015586853, \"error\": 0.6723529398441315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"motion_blur\", \"corruption level\": 5, \"metric\": 0.7335294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.19647057354450226, \"error\": 0.8035294264554977, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.29470588235294115, \"ref\": \"COTT-MC\", \"acc\": 0.6976470351219177, \"error\": 0.3023529648780823, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 1, \"metric\": 0.47411764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.36176469922065735, \"error\": 0.6382353007793427, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.2917647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.6841176152229309, \"error\": 0.3158823847770691, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 2, \"metric\": 0.4717647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.35588234663009644, \"error\": 0.6441176533699036, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.3376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6523529291152954, \"error\": 0.3476470708847046, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 3, \"metric\": 0.4958823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.3311764597892761, \"error\": 0.6688235402107239, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.37176470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.6176470518112183, \"error\": 0.38235294818878174, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 4, \"metric\": 0.5141176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3211764693260193, \"error\": 0.6788235306739807, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.40705882352941175, \"ref\": \"COTT-MC\", \"acc\": 0.5882352590560913, \"error\": 0.4117647409439087, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"pixelate\", \"corruption level\": 5, \"metric\": 0.5376470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.29999998211860657, \"error\": 0.7000000178813934, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.46352941176470586, \"ref\": \"COTT-MC\", \"acc\": 0.5005882382392883, \"error\": 0.49941176176071167, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 1, \"metric\": 0.5888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.2517646849155426, \"error\": 0.7482353150844574, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.5288235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.4111764430999756, \"error\": 0.5888235569000244, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 2, \"metric\": 0.6041176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.21294116973876953, \"error\": 0.7870588302612305, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.35058823529411764, \"ref\": \"COTT-MC\", \"acc\": 0.6370587944984436, \"error\": 0.3629412055015564, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 3, \"metric\": 0.46941176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.3547058701515198, \"error\": 0.6452941298484802, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.59, \"ref\": \"COTT-MC\", \"acc\": 0.36764705181121826, \"error\": 0.6323529481887817, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 4, \"metric\": 0.6735294117647059, \"ref\": \"COTT-MC\", \"acc\": 0.22882352769374847, \"error\": 0.7711764723062515, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.6852941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"saturate\", \"corruption level\": 5, \"metric\": 0.7505882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.17411763966083527, \"error\": 0.8258823603391647, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.34823529411764703, \"ref\": \"COTT-MC\", \"acc\": 0.6529411673545837, \"error\": 0.34705883264541626, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 1, \"metric\": 0.5023529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.3588235080242157, \"error\": 0.6411764919757843, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.49470588235294116, \"ref\": \"COTT-MC\", \"acc\": 0.5082352757453918, \"error\": 0.49176472425460815, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 2, \"metric\": 0.6252941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.2747058570384979, \"error\": 0.7252941429615021, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.6176470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 3, \"metric\": 0.7241176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.2123529314994812, \"error\": 0.7876470685005188, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.7623529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 4, \"metric\": 0.8105882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.13294117152690887, \"error\": 0.8670588284730911, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8705882352941177, \"ref\": \"COTT-MC\", \"acc\": 0.17705881595611572, \"error\": 0.8229411840438843, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"shot_noise\", \"corruption level\": 5, \"metric\": 0.8864705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.11352940648794174, \"error\": 0.8864705935120583, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.4429411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.5641176104545593, \"error\": 0.4358823895454407, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 1, \"metric\": 0.6011764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.29411762952804565, \"error\": 0.7058823704719543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.6052941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.3782352805137634, \"error\": 0.6217647194862366, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 2, \"metric\": 0.678235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.20764705538749695, \"error\": 0.792352944612503, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.6429411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.3552941083908081, \"error\": 0.6447058916091919, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 3, \"metric\": 0.7023529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.20176470279693604, \"error\": 0.798235297203064, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.7152941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 4, \"metric\": 0.7470588235294118, \"ref\": \"COTT-MC\", \"acc\": 0.1558823436498642, \"error\": 0.8441176563501358, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.74, \"ref\": \"COTT-MC\", \"acc\": 0.2047058790922165, \"error\": 0.7952941209077835, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"snow\", \"corruption level\": 5, \"metric\": 0.7564705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.13941176235675812, \"error\": 0.8605882376432419, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.27705882352941175, \"ref\": \"COTT-MC\", \"acc\": 0.7199999690055847, \"error\": 0.2800000309944153, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 1, \"metric\": 0.45, \"ref\": \"COTT-MC\", \"acc\": 0.37882351875305176, \"error\": 0.6211764812469482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.3323529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.6576470136642456, \"error\": 0.3423529863357544, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 2, \"metric\": 0.48764705882352943, \"ref\": \"COTT-MC\", \"acc\": 0.3623529374599457, \"error\": 0.6376470625400543, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.40058823529411763, \"ref\": \"COTT-MC\", \"acc\": 0.6023529171943665, \"error\": 0.39764708280563354, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 3, \"metric\": 0.5570588235294117, \"ref\": \"COTT-MC\", \"acc\": 0.32588234543800354, \"error\": 0.6741176545619965, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.46352941176470586, \"ref\": \"COTT-MC\", \"acc\": 0.518823504447937, \"error\": 0.481176495552063, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 4, \"metric\": 0.5552941176470588, \"ref\": \"COTT-MC\", \"acc\": 0.26823529601097107, \"error\": 0.7317647039890289, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5441176470588235, \"ref\": \"COTT-MC\", \"acc\": 0.42529410123825073, \"error\": 0.5747058987617493, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"spatter\", \"corruption level\": 5, \"metric\": 0.5994117647058823, \"ref\": \"COTT-MC\", \"acc\": 0.24117645621299744, \"error\": 0.7588235437870026, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.33, \"ref\": \"COTT-MC\", \"acc\": 0.6847058534622192, \"error\": 0.31529414653778076, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 1, \"metric\": 0.48, \"ref\": \"COTT-MC\", \"acc\": 0.3641176223754883, \"error\": 0.6358823776245117, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.37588235294117645, \"ref\": \"COTT-MC\", \"acc\": 0.6211764216423035, \"error\": 0.37882357835769653, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 2, \"metric\": 0.5141176470588236, \"ref\": \"COTT-MC\", \"acc\": 0.34058821201324463, \"error\": 0.6594117879867554, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.548235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 3, \"metric\": 0.6429411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.2370588183403015, \"error\": 0.7629411816596985, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.6164705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.37117645144462585, \"error\": 0.6288235485553741, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 4, \"metric\": 0.7047058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.191764697432518, \"error\": 0.808235302567482, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7094117647058824, \"ref\": \"COTT-MC\", \"acc\": 0.2935293912887573, \"error\": 0.7064706087112427, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"speckle_noise\", \"corruption level\": 5, \"metric\": 0.7623529411764706, \"ref\": \"COTT-MC\", \"acc\": 0.16823528707027435, \"error\": 0.8317647129297256, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.41705882352941176, \"ref\": \"COTT-MC\", \"acc\": 0.5764705538749695, \"error\": 0.4235294461250305, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 1, \"metric\": 0.5417647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.294705867767334, \"error\": 0.705294132232666, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.4711764705882353, \"ref\": \"COTT-MC\", \"acc\": 0.5217646956443787, \"error\": 0.47823530435562134, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 2, \"metric\": 0.5735294117647058, \"ref\": \"COTT-MC\", \"acc\": 0.26235294342041016, \"error\": 0.7376470565795898, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5294117647058824, \"ref\": \"COTT-MC\", \"acc\": 0.4664705693721771, \"error\": 0.5335294306278229, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 3, \"metric\": 0.5952941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.24941176176071167, \"error\": 0.7505882382392883, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.5547058823529412, \"ref\": \"COTT-MC\", \"acc\": 0.42823526263237, \"error\": 0.57176473736763, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 4, \"metric\": 0.6217647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.23352940380573273, \"error\": 0.7664705961942673, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.5852941176470589, \"ref\": \"COTT-MC\", \"acc\": 0.3905882239341736, \"error\": 0.6094117760658264, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"zoom_blur\", \"corruption level\": 5, \"metric\": 0.6458823529411765, \"ref\": \"COTT-MC\", \"acc\": 0.21705880761146545, \"error\": 0.7829411923885345, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.6511764705882352, \"ref\": \"COTT-MC\", \"acc\": 0.4411764442920685, \"error\": 0.5588235557079315, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 1, \"metric\": 0.7529411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.23823527991771698, \"error\": 0.761764720082283, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.7888235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.30941176414489746, \"error\": 0.6905882358551025, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 2, \"metric\": 0.8370588235294117, \"ref\": \"COTT-MC\", \"acc\": 0.18529410660266876, \"error\": 0.8147058933973312, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.8929411764705882, \"ref\": \"COTT-MC\", \"acc\": 0.15470588207244873, \"error\": 0.8452941179275513, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 3, \"metric\": 0.9117647058823529, \"ref\": \"COTT-MC\", \"acc\": 0.11058823019266129, \"error\": 0.8894117698073387, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9664705882352941, \"ref\": \"COTT-MC\", \"acc\": 0.08235293626785278, \"error\": 0.9176470637321472, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 4, \"metric\": 0.9576470588235294, \"ref\": \"COTT-MC\", \"acc\": 0.06470587849617004, \"error\": 0.93529412150383, \"subpopulation\": \"novel\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.97, \"ref\": \"COTT-MC\", \"acc\": 0.07235293835401535, \"error\": 0.9276470616459846, \"subpopulation\": \"same\", \"pretrained\": false}, {\"corruption\": \"contrast\", \"corruption level\": 5, \"metric\": 0.9588235294117647, \"ref\": \"COTT-MC\", \"acc\": 0.05529411509633064, \"error\": 0.9447058849036694, \"subpopulation\": \"novel\", \"pretrained\": false}]}, \"mark\": {\"type\": \"point\", \"filled\": true, \"size\": 40}, \"encoding\": {\"color\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"shape\": {\"field\": \"ref\", \"type\": \"nominal\"}, \"x\": {\"field\": \"metric\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"scale\": {\"domain\": [0.15470588235294117, 1]}, \"title\": \"Test Error\", \"type\": \"quantitative\"}}, \"height\": 200, \"title\": \"Living-17\", \"width\": 200}, {\"data\": {\"name\": \"data-55cc1c487e8b42cf39f3db1ac778f185\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"strokeDash\": [5, 8]}, \"encoding\": {\"x\": {\"field\": \"metric\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"error\", \"type\": \"quantitative\"}}}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.17.0.json\", \"datasets\": {\"data-55cc1c487e8b42cf39f3db1ac778f185\": [{\"metric\": 0.15470588235294117, \"error\": 0.15470588235294117}, {\"metric\": 1.0, \"error\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 94,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "get_corr_chart(results[seed_ind], dataset, scale_min=scale_min, scale_max=scale_max) + line_plot"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 95,
   "id": "f6c96c4f",
   "metadata": {},
   "outputs": [],
   "source": [
    "def polyfit(x, y, degree=1):\n",
    "    results = {}\n",
    "\n",
    "    coeffs = np.polyfit(x, y, degree)\n",
    "\n",
    "    results['polynomial'] = coeffs.tolist()\n",
    "\n",
    "    p = np.poly1d(coeffs)\n",
    "\n",
    "    yhat = p(x)                \n",
    "    ybar = np.sum(y)/len(y)          \n",
    "    ssreg = np.sum((yhat - ybar)**2)   \n",
    "    sstot = np.sum((y - ybar)**2)    \n",
    "    results['determination'] = ssreg / sstot\n",
    "\n",
    "    return results"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 96,
   "id": "73c59c8d",
   "metadata": {},
   "outputs": [],
   "source": [
    "from scipy.stats import spearmanr\n",
    "import math"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 97,
   "id": "08834324",
   "metadata": {},
   "outputs": [],
   "source": [
    "def compute_corr_stats(all_results, metric):\n",
    "    if len(all_results) == 0:\n",
    "        return\n",
    "    \n",
    "    results = [i for i in all_results if i['ref'] == metric]\n",
    "    d = [i['metric'] for i in results]\n",
    "    e = [i['error'] for i in results]\n",
    "    \n",
    "    if len(results) > 1:\n",
    "        r2 = polyfit(d, e)['determination']\n",
    "\n",
    "        coef, p = spearmanr(d, e)\n",
    "        slope = polyfit(d, e)['polynomial'][0]\n",
    "        bias = polyfit(d, e)['polynomial'][1]\n",
    "\n",
    "    yhat = np.array(d)\n",
    "    y = np.array(e)\n",
    "    mae = round(np.abs(yhat - y).mean() * 100, 2)\n",
    "    \n",
    "    return mae"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 98,
   "id": "9eb490d2",
   "metadata": {},
   "outputs": [],
   "source": [
    "def generate_summary(results, seeds, subpop):\n",
    "    pop_sum = []\n",
    "    for i, seed in enumerate(seeds):\n",
    "        maes = []\n",
    "        for metric in metrics:\n",
    "            pop_result = [r for r in results[i] if r['subpopulation'] == subpop]\n",
    "            if len(pop_result) == 0:\n",
    "                return\n",
    "            maes.append(\n",
    "                compute_corr_stats(pop_result, metric)\n",
    "            )\n",
    "        pop_sum.append(maes)\n",
    "\n",
    "    pop_sum = np.array(pop_sum).T\n",
    "    for j, metric in enumerate(metrics):\n",
    "        print(f'{metric}:', round(pop_sum[j].mean(), 2), u\"\\u00B1\", round(pop_sum[j].std(), 2))\n",
    "    "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 99,
   "id": "23828d93",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "----- same pop results -----\n",
      "AC: 11.36 ± 0.0\n",
      "DoC: 11.57 ± 0.0\n",
      "IM: 13.38 ± 0.0\n",
      "GDE: nan ± nan\n",
      "ATC-MC: 5.4 ± 0.0\n",
      "ATC-NE: 4.64 ± 0.0\n",
      "COT: 4.16 ± 0.0\n",
      "COTT-MC: 2.24 ± 0.0\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/var/tmp/lu35/ipykernel_3738105/2605032691.py:18: RuntimeWarning: Mean of empty slice.\n",
      "  mae = round(np.abs(yhat - y).mean() * 100, 2)\n",
      "/usr/workspace/lu35/anaconda3/envs/ood/lib/python3.9/site-packages/numpy/core/_methods.py:190: RuntimeWarning: invalid value encountered in double_scalars\n",
      "  ret = ret.dtype.type(ret / rcount)\n"
     ]
    }
   ],
   "source": [
    "print(\"----- same pop results -----\")\n",
    "generate_summary(results, seeds, 'same')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 100,
   "id": "bf70a29c",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "----- natural pop results -----\n"
     ]
    }
   ],
   "source": [
    "print(\"----- natural pop results -----\")\n",
    "generate_summary(results, seeds, 'natural')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 101,
   "id": "05c3ac30",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "----- novel pop results -----\n",
      "AC: 25.9 ± 0.0\n",
      "DoC: 26.11 ± 0.0\n",
      "IM: 28.54 ± 0.0\n",
      "GDE: nan ± nan\n",
      "ATC-MC: 16.43 ± 0.0\n",
      "ATC-NE: 14.3 ± 0.0\n",
      "COT: 17.1 ± 0.0\n",
      "COTT-MC: 10.59 ± 0.0\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/var/tmp/lu35/ipykernel_3738105/2605032691.py:18: RuntimeWarning: Mean of empty slice.\n",
      "  mae = round(np.abs(yhat - y).mean() * 100, 2)\n"
     ]
    }
   ],
   "source": [
    "print(\"----- novel pop results -----\")\n",
    "generate_summary(results, seeds, 'novel')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "f4599063",
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "ood",
   "language": "python",
   "name": "ood"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.13"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
